@@ -134,11 +134,19 @@ class _Asset:
             fn, self.namespace, self.ins or {}, self.non_argument_deps
         )
 
+        partition_fn: Optional[Callable] = None
+        if self.partitions_def:
+
+            def partition_fn(context):  # pylint: disable=function-redefined
+                return [context.partition_key]
+
         out = Out(
             asset_key=AssetKey(list(filter(None, [self.namespace, asset_name]))),
             metadata=self.metadata or {},
             io_manager_key=self.io_manager_key,
             dagster_type=self.dagster_type,
+            asset_partitions_def=self.partitions_def,
+            asset_partitions=partition_fn,
         )
         op = _Op(
             name=asset_name,
@@ -152,7 +160,6 @@ class _Asset:
         )(fn)
 
         out_asset_key = AssetKey(list(filter(None, [self.namespace, asset_name])))
-
         return AssetsDefinition(
             input_names_by_asset_key={
                 in_def.asset_key: input_name for input_name, in_def in ins_by_input_names.items()
