@@ -42,22 +42,24 @@ class AssetKey(NamedTuple("_AssetKey", [("path", Union[Tuple[str, ...], List[str
 
     .. code-block:: python
 
-        @solid
-        def emit_metadata_solid(context, df):
+        from dagster import op
+
+        @op
+        def emit_metadata(context, df):
             yield AssetMaterialization(
                 asset_key=AssetKey('flat_asset_key'),
                 metadata={"text_metadata": "Text-based metadata for this event"},
             )
 
-        @solid
-        def structured_asset_key_solid(context, df):
+        @op
+        def structured_asset_key(context, df):
             yield AssetMaterialization(
                 asset_key=AssetKey(['parent', 'child', 'grandchild']),
                 metadata={"text_metadata": "Text-based metadata for this event"},
             )
 
-        @solid
-        def structured_asset_key_solid_2(context, df):
+        @op
+        def structured_asset_key_2(context, df):
             yield AssetMaterialization(
                 asset_key=AssetKey(('parent', 'child', 'grandchild')),
                 metadata={"text_metadata": "Text-based metadata for this event"},
@@ -147,19 +149,19 @@ class Output(
         ],
     )
 ):
-    """Event corresponding to one of a solid's outputs.
+    """Event corresponding to one of a op's outputs.
 
-    Solid compute functions must explicitly yield events of this type when they have more than
-    one output, or when they also yield events of other types, or when defining a solid using the
-    :py:class:`SolidDefinition` API directly.
+    Op compute functions must explicitly yield events of this type when they have more than
+    one output, or when they also yield events of other types, or when defining a op using the
+    :py:class:`OpDefinition` API directly.
 
-    Outputs are values produced by solids that will be consumed by downstream solids in a pipeline.
-    They are type-checked at solid boundaries when their corresponding :py:class:`OutputDefinition`
-    or the downstream :py:class:`InputDefinition` is typed.
+    Outputs are values produced by ops that will be consumed by downstream ops in a job.
+    They are type-checked at op boundaries when their corresponding :py:class:`Out`
+    or the downstream :py:class:`In` is typed.
 
     Args:
         value (Any): The value returned by the compute function.
-        output_name (Optional[str]): Name of the corresponding output definition. (default:
+        output_name (Optional[str]): Name of the corresponding out. (default:
             "result")
         metadata_entries (Optional[Union[EventMetadataEntry, PartitionMetadataEntry]]):
             (Experimental) A set of metadata entries to attach to events related to this Output.
@@ -209,7 +211,7 @@ class DynamicOutput(
 ):
     """
     (Experimental) Variant of :py:class:`Output <dagster.Output>` used to support
-    dynamic mapping & collect. Each ``DynamicOutput`` produced by a solid represents
+    dynamic mapping & collect. Each ``DynamicOutput`` produced by an op represents
     one item in a set that can be processed individually with ``map`` or gathered
     with ``collect``.
 
@@ -220,10 +222,10 @@ class DynamicOutput(
             The value returned by the compute function.
         mapping_key (str):
             The key that uniquely identifies this dynamic value relative to its peers.
-            This key will be used to identify the downstream solids when mapped, ie
-            ``mapped_solid[example_mapping_key]``
+            This key will be used to identify the downstream ops when mapped, ie
+            ``mapped_op[example_mapping_key]``
         output_name (Optional[str]):
-            Name of the corresponding :py:class:`DynamicOutputDefinition` defined on the solid.
+            Name of the corresponding :py:class:`DynamicOut` defined on the op.
             (default: "result")
         metadata_entries (Optional[Union[EventMetadataEntry, PartitionMetadataEntry]]):
             (Experimental) A set of metadata entries to attach to events related to this output.
@@ -263,6 +265,63 @@ class DynamicOutput(
 MetadataValues = Union[str, float, int, Dict, EventMetadataEntry]
 
 
+@whitelist_for_serdes
+class AssetObservation(
+    NamedTuple(
+        "_AssetObservation",
+        [
+            ("asset_key", AssetKey),
+            ("metadata_entries", List[EventMetadataEntry]),
+            ("partition", Optional[str]),
+        ],
+    )
+):
+    """Event that captures metadata about an asset at a point in time.
+
+    Args:
+        asset_key (Union[str, List[str], AssetKey]): A key to identify the asset.
+        metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the asset.
+        partition (Optional[str]): The name of a partition of the asset that the metadata
+            corresponds to.
+        metadata (Optional[Dict[str, Union[str, float, int, Dict, EventMetadata]]]):
+            Arbitrary metadata about the asset.  Keys are displayed string labels, and values are
+            one of the following: string, float, int, JSON-serializable dict, JSON-serializable
+            list, and one of the data classes returned by a EventMetadata static method.
+    """
+
+    def __new__(
+        cls,
+        asset_key: Union[List[str], AssetKey, str],
+        metadata_entries: Optional[List[EventMetadataEntry]] = None,
+        partition: Optional[str] = None,
+        metadata: Optional[Dict[str, MetadataValues]] = None,
+    ):
+        if isinstance(asset_key, AssetKey):
+            check.inst_param(asset_key, "asset_key", AssetKey)
+        elif isinstance(asset_key, str):
+            asset_key = AssetKey(parse_asset_key_string(asset_key))
+        elif isinstance(asset_key, list):
+            check.is_list(asset_key, of_type=str)
+            asset_key = AssetKey(asset_key)
+        else:
+            check.is_tuple(asset_key, of_type=str)
+            asset_key = AssetKey(asset_key)
+
+        metadata = check.opt_dict_param(metadata, "metadata", key_type=str)
+        metadata_entries = check.opt_list_param(
+            metadata_entries, "metadata_entries", of_type=EventMetadataEntry
+        )
+
+        return super(AssetObservation, cls).__new__(
+            cls,
+            asset_key=asset_key,
+            metadata_entries=cast(
+                List[EventMetadataEntry], parse_metadata(metadata, metadata_entries)
+            ),
+            partition=check.opt_str_param(partition, "partition"),
+        )
+
+
 @whitelist_for_serdes
 class AssetMaterialization(
     NamedTuple(
@@ -276,19 +335,19 @@ class AssetMaterialization(
         ],
     )
 ):
-    """Event indicating that a solid has materialized an asset.
+    """Event indicating that an op has materialized an asset.
 
-    Solid compute functions may yield events of this type whenever they wish to indicate to the
+    Op compute functions may yield events of this type whenever they wish to indicate to the
     Dagster framework (and the end user) that they have produced a materialized value as a
     side effect of computation. Unlike outputs, asset materializations can not be passed to other
-    solids, and their persistence is controlled by solid logic, rather than by the Dagster
+    ops, and their persistence is controlled by op logic, rather than by the Dagster
     framework.
 
-    Solid authors should use these events to organize metadata about the side effects of their
+    Op authors should use these events to organize metadata about the side effects of their
     computations, enabling tooling like the Assets dashboard in Dagit.
 
     Args:
-        asset_key (Union[str, List[str], AssetKey]): A key to identify the materialized asset across pipeline
+        asset_key (Union[str, List[str], AssetKey]): A key to identify the materialized asset across job
             runs
         description (Optional[str]): A longer human-readable description of the materialized value.
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
@@ -298,7 +357,7 @@ class AssetMaterialization(
             materialization.  Used for search and organization of the asset entry in the asset
             catalog in Dagit.
         metadata (Optional[Dict[str, Union[str, float, int, Dict, EventMetadata]]]):
-            Arbitrary metadata about the failure.  Keys are displayed string labels, and values are
+            Arbitrary metadata about the asset.  Keys are displayed string labels, and values are
             one of the following: string, float, int, JSON-serializable dict, JSON-serializable
             list, and one of the data classes returned by a EventMetadata static method.
     """
@@ -370,10 +429,10 @@ class AssetMaterialization(
 
 class MaterializationSerializer(DefaultNamedTupleSerializer):
     @classmethod
-    def value_from_storage_dict(cls, storage_dict, klass, args_for_class):
+    def value_from_unpacked(cls, unpacked_dict, klass):
         # override the default `from_storage_dict` implementation in order to skip the deprecation
         # warning for historical Materialization events, loaded from event_log storage
-        return Materialization(skip_deprecation_warning=True, **storage_dict)
+        return Materialization(skip_deprecation_warning=True, **unpacked_dict)
 
 
 @whitelist_for_serdes(serializer=MaterializationSerializer)
@@ -390,12 +449,12 @@ class Materialization(
         ],
     )
 ):
-    """Event indicating that a solid has materialized a value.
+    """Event indicating that an op has materialized a value.
 
     Solid compute functions may yield events of this type whenever they wish to indicate to the
     Dagster framework (and the end user) that they have produced a materialized value as a
-    side effect of computation. Unlike outputs, materializations can not be passed to other solids,
-    and their persistence is controlled by solid logic, rather than by the Dagster framework.
+    side effect of computation. Unlike outputs, materializations can not be passed to other ops,
+    and their persistence is controlled by op logic, rather than by the Dagster framework.
 
     Solid authors should use these events to organize metadata about the side effects of their
     computations to enable downstream tooling like artifact catalogues and diff tools.
@@ -406,7 +465,7 @@ class Materialization(
         metadata_entries (Optional[List[EventMetadataEntry]]): Arbitrary metadata about the
             materialized value.
         asset_key (Optional[Union[str, AssetKey]]): An optional parameter to identify the materialized asset
-            across pipeline runs
+            across runs
         partition (Optional[str]): The name of the partition that was materialized.
         tags (Optional[Dict[str, str]]): (Experimental) Tag metadata for a given asset
             materialization.  Used for search and organization of the asset entry in the asset
@@ -490,7 +549,7 @@ class ExpectationResult(
 ):
     """Event corresponding to a data quality test.
 
-    Solid compute functions may yield events of this type whenever they wish to indicate to the
+    Op compute functions may yield events of this type whenever they wish to indicate to the
     Dagster framework (and the end user) that a data quality test has produced a (positive or
     negative) result.
 
@@ -585,9 +644,9 @@ class TypeCheck(
 
 
 class Failure(Exception):
-    """Event indicating solid failure.
+    """Event indicating op failure.
 
-    Raise events of this type from within solid compute functions or custom type checks in order to
+    Raise events of this type from within op compute functions or custom type checks in order to
     indicate an unrecoverable failure in user code to the Dagster machinery and return
     structured metadata about the failure.
 
@@ -619,7 +678,7 @@ class Failure(Exception):
 
 class RetryRequested(Exception):
     """
-    An exception to raise from a solid to indicate that it should be retried.
+    An exception to raise from an op to indicate that it should be retried.
 
     Args:
         max_retries (Optional[int]):
@@ -632,7 +691,7 @@ class RetryRequested(Exception):
 
         .. code-block:: python
 
-            @solid
+            @op
             def flakes():
                 try:
                     flakey_operation()
