@@ -7,6 +7,7 @@ from typing import Any, Callable, Dict, Generic, List, NamedTuple, Optional, Typ
 
 import pendulum
 from dagster import check
+from dagster.serdes import whitelist_for_serdes
 from dateutil.relativedelta import relativedelta
 
 from ...seven.compat.pendulum import PendulumDateTime, to_timezone
@@ -56,6 +57,11 @@ class Partition(Generic[T]):
     def name(self) -> str:
         return self._name
 
+    def __eq__(self, other) -> bool:
+        return (
+            isinstance(other, Partition) and self.value == other.value and self.name == other.name
+        )
+
 
 def schedule_partition_range(
     start: datetime,
@@ -124,6 +130,7 @@ def schedule_partition_range(
     return partitions
 
 
+@whitelist_for_serdes
 class ScheduleType(Enum):
     HOURLY = "HOURLY"
     DAILY = "DAILY"
@@ -159,6 +166,10 @@ class PartitionsDefinition(ABC, Generic[T]):
     def get_partitions(self, current_time: Optional[datetime] = None) -> List[Partition[T]]:
         ...
 
+    def __str__(self) -> str:
+        joined_keys = ", ".join([f"'{key}'" for key in self.get_partition_keys()])
+        return joined_keys
+
     def get_partition_keys(self, current_time: Optional[datetime] = None) -> List[str]:
         return [partition.name for partition in self.get_partitions(current_time)]
 
@@ -169,7 +180,7 @@ class PartitionsDefinition(ABC, Generic[T]):
 
 
 class StaticPartitionsDefinition(
-    PartitionsDefinition[str]
+    PartitionsDefinition[str],
 ):  # pylint: disable=unsubscriptable-object
     def __init__(self, partition_keys: List[str]):
         check.list_param(partition_keys, "partition_keys", of_type=str)
@@ -180,6 +191,15 @@ class StaticPartitionsDefinition(
     ) -> List[Partition[str]]:
         return self._partitions
 
+    def __eq__(self, other) -> bool:
+        return (
+            isinstance(other, StaticPartitionsDefinition)
+            and self._partitions == other.get_partitions()
+        )
+
+    def __repr__(self) -> str:
+        return f"{type(self).__name__}(partition_keys={[p.name for p in self._partitions]})"
+
 
 class ScheduleTimeBasedPartitionsDefinition(
     PartitionsDefinition[datetime],  # pylint: disable=unsubscriptable-object
@@ -685,11 +705,13 @@ class PartitionedConfig(Generic[T]):
         self,
         partitions_def: PartitionsDefinition[T],  # pylint: disable=unsubscriptable-object
         run_config_for_partition_fn: Callable[[Partition[T]], Dict[str, Any]],
+        decorated_fn: Optional[Callable[..., Dict[str, Any]]] = None,
     ):
         self._partitions = check.inst_param(partitions_def, "partitions_def", PartitionsDefinition)
         self._run_config_for_partition_fn = check.callable_param(
             run_config_for_partition_fn, "run_config_for_partition_fn"
         )
+        self._decorated_fn = decorated_fn
 
     @property
     def partitions_def(self) -> PartitionsDefinition[T]:  # pylint: disable=unsubscriptable-object
@@ -714,6 +736,15 @@ class PartitionedConfig(Generic[T]):
             )
         return self.run_config_for_partition_fn(matching[0])
 
+    def __call__(self, *args, **kwargs):
+        if self._decorated_fn is None:
+            raise DagsterInvalidInvocationError(
+                "Only PartitionedConfig objects created using one of the partitioned config "
+                "decorators can be directly invoked."
+            )
+        else:
+            return self._decorated_fn(*args, **kwargs)
+
 
 def static_partitioned_config(
     partition_keys: List[str],
@@ -749,6 +780,7 @@ def static_partitioned_config(
         return PartitionedConfig(
             partitions_def=StaticPartitionsDefinition(partition_keys),
             run_config_for_partition_fn=_run_config_wrapper,
+            decorated_fn=fn,
         )
 
     return inner
@@ -783,6 +815,7 @@ def dynamic_partitioned_config(
         return PartitionedConfig(
             partitions_def=DynamicPartitionsDefinition(partition_fn),
             run_config_for_partition_fn=_run_config_wrapper,
+            decorated_fn=fn,
         )
 
     return inner
@@ -791,19 +824,18 @@ def dynamic_partitioned_config(
 def get_cron_schedule(
     schedule_type: ScheduleType,
     time_of_day: time = time(0, 0),
-    day_of_week: Optional[int] = 0,
+    execution_day: Optional[int] = None,
 ) -> str:
     minute = time_of_day.minute
     hour = time_of_day.hour
-    day = day_of_week
 
     if schedule_type is ScheduleType.HOURLY:
         return f"{minute} * * * *"
     elif schedule_type is ScheduleType.DAILY:
         return f"{minute} {hour} * * *"
     elif schedule_type is ScheduleType.WEEKLY:
-        return f"{minute} {hour} * * {day}"
+        return f"{minute} {hour} * * {execution_day if execution_day != None else 0}"
     elif schedule_type is ScheduleType.MONTHLY:
-        return f"{minute} {hour} {day} * *"
+        return f"{minute} {hour} {execution_day if execution_day != None else 1} * *"
     else:
         check.assert_never(schedule_type)
