@@ -8,6 +8,7 @@ from dagster import check
 from dagster.core.definitions import (
     AssetKey,
     AssetMaterialization,
+    AssetObservation,
     EventMetadataEntry,
     ExpectationResult,
     HookDefinition,
@@ -59,6 +60,7 @@ if TYPE_CHECKING:
         "HandledOutputData",
         "LoadedInputData",
         "ComputeLogsCaptureData",
+        "AssetObservationData",
     ]
 
 
@@ -76,18 +78,32 @@ class DagsterEventType(Enum):
     STEP_RESTARTED = "STEP_RESTARTED"
 
     ASSET_MATERIALIZATION = "ASSET_MATERIALIZATION"
+    ASSET_OBSERVATION = "ASSET_OBSERVATION"
     STEP_EXPECTATION_RESULT = "STEP_EXPECTATION_RESULT"
 
-    PIPELINE_ENQUEUED = "PIPELINE_ENQUEUED"
-    PIPELINE_DEQUEUED = "PIPELINE_DEQUEUED"
-    PIPELINE_STARTING = "PIPELINE_STARTING"  # Launch is happening, execution hasn't started yet
+    # We want to display RUN_* events in dagit and in our LogManager output, but in order to
+    # support backcompat for our storage layer, we need to keep the persisted value to be strings
+    # of the form "PIPELINE_*".  We may have user code that pass in the DagsterEventType
+    # enum values into storage APIs (like get_event_records, which takes in an EventRecordsFilter).
+    RUN_ENQUEUED = "PIPELINE_ENQUEUED"
+    RUN_DEQUEUED = "PIPELINE_DEQUEUED"
+    RUN_STARTING = "PIPELINE_STARTING"  # Launch is happening, execution hasn't started yet
+    RUN_START = "PIPELINE_START"  # Execution has started
+    RUN_SUCCESS = "PIPELINE_SUCCESS"
+    RUN_FAILURE = "PIPELINE_FAILURE"
+    RUN_CANCELING = "PIPELINE_CANCELING"
+    RUN_CANCELED = "PIPELINE_CANCELED"
 
-    PIPELINE_START = "PIPELINE_START"  # Execution has started
-    PIPELINE_SUCCESS = "PIPELINE_SUCCESS"
-    PIPELINE_FAILURE = "PIPELINE_FAILURE"
-
-    PIPELINE_CANCELING = "PIPELINE_CANCELING"
-    PIPELINE_CANCELED = "PIPELINE_CANCELED"
+    # Keep these legacy enum values around, to keep back-compatability for user code that might be
+    # using these constants to filter event records
+    PIPELINE_ENQUEUED = RUN_ENQUEUED
+    PIPELINE_DEQUEUED = RUN_DEQUEUED
+    PIPELINE_STARTING = RUN_STARTING
+    PIPELINE_START = RUN_START
+    PIPELINE_SUCCESS = RUN_SUCCESS
+    PIPELINE_FAILURE = RUN_FAILURE
+    PIPELINE_CANCELING = RUN_CANCELING
+    PIPELINE_CANCELED = RUN_CANCELED
 
     OBJECT_STORE_OPERATION = "OBJECT_STORE_OPERATION"
     ASSET_STORE_OPERATION = "ASSET_STORE_OPERATION"
@@ -105,6 +121,17 @@ class DagsterEventType(Enum):
     LOGS_CAPTURED = "LOGS_CAPTURED"
 
 
+EVENT_TYPE_VALUE_TO_DISPLAY_STRING = {
+    "PIPELINE_ENQUEUED": "RUN_ENQUEUED",
+    "PIPELINE_DEQUEUED": "RUN_DEQUEUED",
+    "PIPELINE_STARTING": "RUN_STARTING",
+    "PIPELINE_START": "RUN_START",
+    "PIPELINE_SUCCESS": "RUN_SUCCESS",
+    "PIPELINE_FAILURE": "RUN_FAILURE",
+    "PIPELINE_CANCELING": "RUN_CANCELING",
+    "PIPELINE_CANCELED": "RUN_CANCELED",
+}
+
 STEP_EVENTS = {
     DagsterEventType.STEP_INPUT,
     DagsterEventType.STEP_START,
@@ -113,6 +140,7 @@ STEP_EVENTS = {
     DagsterEventType.STEP_SUCCESS,
     DagsterEventType.STEP_SKIPPED,
     DagsterEventType.ASSET_MATERIALIZATION,
+    DagsterEventType.ASSET_OBSERVATION,
     DagsterEventType.STEP_EXPECTATION_RESULT,
     DagsterEventType.OBJECT_STORE_OPERATION,
     DagsterEventType.HANDLED_OUTPUT,
@@ -122,20 +150,20 @@ STEP_EVENTS = {
 }
 
 FAILURE_EVENTS = {
-    DagsterEventType.PIPELINE_FAILURE,
+    DagsterEventType.RUN_FAILURE,
     DagsterEventType.STEP_FAILURE,
-    DagsterEventType.PIPELINE_CANCELED,
+    DagsterEventType.RUN_CANCELED,
 }
 
 PIPELINE_EVENTS = {
-    DagsterEventType.PIPELINE_ENQUEUED,
-    DagsterEventType.PIPELINE_DEQUEUED,
-    DagsterEventType.PIPELINE_STARTING,
-    DagsterEventType.PIPELINE_START,
-    DagsterEventType.PIPELINE_SUCCESS,
-    DagsterEventType.PIPELINE_FAILURE,
-    DagsterEventType.PIPELINE_CANCELING,
-    DagsterEventType.PIPELINE_CANCELED,
+    DagsterEventType.RUN_ENQUEUED,
+    DagsterEventType.RUN_DEQUEUED,
+    DagsterEventType.RUN_STARTING,
+    DagsterEventType.RUN_START,
+    DagsterEventType.RUN_SUCCESS,
+    DagsterEventType.RUN_FAILURE,
+    DagsterEventType.RUN_CANCELING,
+    DagsterEventType.RUN_CANCELED,
 }
 
 HOOK_EVENTS = {
@@ -151,13 +179,13 @@ ALERT_EVENTS = {
 
 
 EVENT_TYPE_TO_PIPELINE_RUN_STATUS = {
-    DagsterEventType.PIPELINE_START: PipelineRunStatus.STARTED,
-    DagsterEventType.PIPELINE_SUCCESS: PipelineRunStatus.SUCCESS,
-    DagsterEventType.PIPELINE_FAILURE: PipelineRunStatus.FAILURE,
-    DagsterEventType.PIPELINE_ENQUEUED: PipelineRunStatus.QUEUED,
-    DagsterEventType.PIPELINE_STARTING: PipelineRunStatus.STARTING,
-    DagsterEventType.PIPELINE_CANCELING: PipelineRunStatus.CANCELING,
-    DagsterEventType.PIPELINE_CANCELED: PipelineRunStatus.CANCELED,
+    DagsterEventType.RUN_START: PipelineRunStatus.STARTED,
+    DagsterEventType.RUN_SUCCESS: PipelineRunStatus.SUCCESS,
+    DagsterEventType.RUN_FAILURE: PipelineRunStatus.FAILURE,
+    DagsterEventType.RUN_ENQUEUED: PipelineRunStatus.QUEUED,
+    DagsterEventType.RUN_STARTING: PipelineRunStatus.STARTING,
+    DagsterEventType.RUN_CANCELING: PipelineRunStatus.CANCELING,
+    DagsterEventType.RUN_CANCELED: PipelineRunStatus.CANCELED,
 }
 
 PIPELINE_RUN_STATUS_TO_EVENT_TYPE = {v: k for k, v in EVENT_TYPE_TO_PIPELINE_RUN_STATUS.items()}
@@ -201,47 +229,32 @@ def _validate_event_specific_data(
 
 
 def log_step_event(step_context: IStepContext, event: "DagsterEvent") -> None:
-
     event_type = DagsterEventType(event.event_type_value)
-    log_fn = step_context.log.error if event_type in FAILURE_EVENTS else step_context.log.debug
+    log_level = logging.ERROR if event_type in FAILURE_EVENTS else logging.DEBUG
 
-    log_fn(
-        event.message
-        or "{event_type} for step {step_key}".format(
-            event_type=event_type, step_key=step_context.step.key
-        ),
+    step_context.log.log_dagster_event(
+        level=log_level,
+        msg=event.message or f"{event_type} for step {step_context.step.key}",
         dagster_event=event,
-        pipeline_name=step_context.pipeline_name,
     )
 
 
-def log_pipeline_event(
-    pipeline_context: IPlanContext, event: "DagsterEvent", step_key: Optional[str]
-) -> None:
+def log_pipeline_event(pipeline_context: IPlanContext, event: "DagsterEvent") -> None:
     event_type = DagsterEventType(event.event_type_value)
+    log_level = logging.ERROR if event_type in FAILURE_EVENTS else logging.DEBUG
 
-    log_fn = (
-        pipeline_context.log.error if event_type in FAILURE_EVENTS else pipeline_context.log.debug
-    )
-
-    log_fn(
-        event.message
-        or "{event_type} for pipeline {pipeline_name}".format(
-            event_type=event_type, pipeline_name=pipeline_context.pipeline_name
-        ),
+    pipeline_context.log.log_dagster_event(
+        level=log_level,
+        msg=event.message or f"{event_type} for pipeline {pipeline_context.pipeline_name}",
         dagster_event=event,
-        pipeline_name=pipeline_context.pipeline_name,
-        step_key=step_key,
     )
 
 
-def log_resource_event(
-    log_manager: DagsterLogManager, pipeline_name: str, event: "DagsterEvent"
-) -> None:
+def log_resource_event(log_manager: DagsterLogManager, event: "DagsterEvent") -> None:
     event_specific_data = cast(EngineEventData, event.event_specific_data)
 
-    log_fn = log_manager.error if event_specific_data.error else log_manager.debug
-    log_fn(event.message, dagster_event=event, pipeline_name=pipeline_name, step_key=event.step_key)
+    log_level = logging.ERROR if event_specific_data.error else logging.DEBUG
+    log_manager.log_dagster_event(level=log_level, msg=event.message or "", dagster_event=event)
 
 
 @whitelist_for_serdes
@@ -269,7 +282,6 @@ class DagsterEvent(
     Attributes:
         event_type_value (str): Value for a DagsterEventType.
         pipeline_name (str)
-        step_key (str)
         solid_handle (NodeHandle)
         step_kind_value (str): Value for a StepKind.
         logging_tags (Dict[str, str])
@@ -323,8 +335,8 @@ class DagsterEvent(
             step_handle=step_handle,
             pid=os.getpid(),
         )
-        step_key = step_handle.to_key() if step_handle else None
-        log_pipeline_event(pipeline_context, event, step_key)
+
+        log_pipeline_event(pipeline_context, event)
 
         return event
 
@@ -347,7 +359,7 @@ class DagsterEvent(
             step_handle=execution_plan.step_handle_for_single_step_plans(),
             pid=os.getpid(),
         )
-        log_resource_event(log_manager, pipeline_name, event)
+        log_resource_event(log_manager, event)
         return event
 
     def __new__(
@@ -452,11 +464,11 @@ class DagsterEvent(
 
     @property
     def is_pipeline_success(self) -> bool:
-        return self.event_type == DagsterEventType.PIPELINE_SUCCESS
+        return self.event_type == DagsterEventType.RUN_SUCCESS
 
     @property
     def is_pipeline_failure(self) -> bool:
-        return self.event_type == DagsterEventType.PIPELINE_FAILURE
+        return self.event_type == DagsterEventType.RUN_FAILURE
 
     @property
     def is_failure(self) -> bool:
@@ -482,17 +494,27 @@ class DagsterEvent(
     def is_step_materialization(self) -> bool:
         return self.event_type == DagsterEventType.ASSET_MATERIALIZATION
 
+    @property
+    def is_asset_observation(self) -> bool:
+        return self.event_type == DagsterEventType.ASSET_OBSERVATION
+
     @property
     def asset_key(self) -> Optional[AssetKey]:
-        if self.event_type != DagsterEventType.ASSET_MATERIALIZATION:
+        if self.event_type == DagsterEventType.ASSET_MATERIALIZATION:
+            return self.step_materialization_data.materialization.asset_key
+        elif self.event_type == DagsterEventType.ASSET_OBSERVATION:
+            return self.asset_observation_data.asset_observation.asset_key
+        else:
             return None
-        return self.step_materialization_data.materialization.asset_key
 
     @property
     def partition(self) -> Optional[str]:
-        if self.event_type != DagsterEventType.ASSET_MATERIALIZATION:
+        if self.event_type == DagsterEventType.ASSET_MATERIALIZATION:
+            return self.step_materialization_data.materialization.partition
+        elif self.event_type == DagsterEventType.ASSET_OBSERVATION:
+            return self.asset_observation_data.asset_observation.partition
+        else:
             return None
-        return self.step_materialization_data.materialization.partition
 
     @property
     def step_input_data(self) -> "StepInputData":
@@ -534,6 +556,11 @@ class DagsterEvent(
         )
         return cast(StepMaterializationData, self.event_specific_data)
 
+    @property
+    def asset_observation_data(self) -> "AssetObservationData":
+        _assert_type("asset_observation_data", DagsterEventType.ASSET_OBSERVATION, self.event_type)
+        return cast(AssetObservationData, self.event_specific_data)
+
     @property
     def step_expectation_result_data(self) -> "StepExpectationResultData":
         _assert_type(
@@ -545,7 +572,7 @@ class DagsterEvent(
 
     @property
     def pipeline_failure_data(self) -> "PipelineFailureData":
-        _assert_type("pipeline_failure_data", DagsterEventType.PIPELINE_FAILURE, self.event_type)
+        _assert_type("pipeline_failure_data", DagsterEventType.RUN_FAILURE, self.event_type)
         return cast(PipelineFailureData, self.event_specific_data)
 
     @property
@@ -716,6 +743,16 @@ class DagsterEvent(
             ),
         )
 
+    @staticmethod
+    def asset_observation(
+        step_context: IStepContext, observation: AssetObservation
+    ) -> "DagsterEvent":
+        return DagsterEvent.from_step(
+            event_type=DagsterEventType.ASSET_OBSERVATION,
+            step_context=step_context,
+            event_specific_data=AssetObservationData(observation),
+        )
+
     @staticmethod
     def step_expectation_result(
         step_context: IStepContext, expectation_result: ExpectationResult
@@ -739,9 +776,9 @@ class DagsterEvent(
     @staticmethod
     def pipeline_start(pipeline_context: IPlanContext) -> "DagsterEvent":
         return DagsterEvent.from_pipeline(
-            DagsterEventType.PIPELINE_START,
+            DagsterEventType.RUN_START,
             pipeline_context,
-            message='Started execution of pipeline "{pipeline_name}".'.format(
+            message='Started execution of run for "{pipeline_name}".'.format(
                 pipeline_name=pipeline_context.pipeline_name
             ),
         )
@@ -749,9 +786,9 @@ class DagsterEvent(
     @staticmethod
     def pipeline_success(pipeline_context: IPlanContext) -> "DagsterEvent":
         return DagsterEvent.from_pipeline(
-            DagsterEventType.PIPELINE_SUCCESS,
+            DagsterEventType.RUN_SUCCESS,
             pipeline_context,
-            message='Finished execution of pipeline "{pipeline_name}".'.format(
+            message='Finished execution of run for "{pipeline_name}".'.format(
                 pipeline_name=pipeline_context.pipeline_name
             ),
         )
@@ -765,9 +802,9 @@ class DagsterEvent(
         check.str_param(context_msg, "context_msg")
         if isinstance(pipeline_context_or_name, IPlanContext):
             return DagsterEvent.from_pipeline(
-                DagsterEventType.PIPELINE_FAILURE,
+                DagsterEventType.RUN_FAILURE,
                 pipeline_context_or_name,
-                message='Execution of pipeline "{pipeline_name}" failed. {context_msg}'.format(
+                message='Execution of run for "{pipeline_name}" failed. {context_msg}'.format(
                     pipeline_name=pipeline_context_or_name.pipeline_name,
                     context_msg=context_msg,
                 ),
@@ -778,10 +815,10 @@ class DagsterEvent(
             # built and so can't use from_pipeline
             check.str_param(pipeline_context_or_name, "pipeline_name")
             event = DagsterEvent(
-                event_type_value=DagsterEventType.PIPELINE_FAILURE.value,
+                event_type_value=DagsterEventType.RUN_FAILURE.value,
                 pipeline_name=pipeline_context_or_name,
                 event_specific_data=PipelineFailureData(error_info),
-                message='Execution of pipeline "{pipeline_name}" failed. {context_msg}'.format(
+                message='Execution of run for "{pipeline_name}" failed. {context_msg}'.format(
                     pipeline_name=pipeline_context_or_name,
                     context_msg=context_msg,
                 ),
@@ -794,9 +831,9 @@ class DagsterEvent(
         pipeline_context: IPlanContext, error_info: Optional[SerializableErrorInfo] = None
     ) -> "DagsterEvent":
         return DagsterEvent.from_pipeline(
-            DagsterEventType.PIPELINE_CANCELED,
+            DagsterEventType.RUN_CANCELED,
             pipeline_context,
-            message='Execution of pipeline "{pipeline_name}" canceled.'.format(
+            message='Execution of run for "{pipeline_name}" canceled.'.format(
                 pipeline_name=pipeline_context.pipeline_name
             ),
             event_specific_data=PipelineCanceledData(
@@ -1049,14 +1086,12 @@ class DagsterEvent(
             step_kind_value=step_context.step.kind.value,
             logging_tags=step_context.logging_tags,
             message=(
-                'Finished the execution of hook "{hook_name}" triggered for solid "{solid_name}".'
+                'Finished the execution of hook "{hook_name}" triggered for "{solid_name}".'
             ).format(hook_name=hook_def.name, solid_name=step_context.solid.name),
         )
 
-        step_context.log.debug(
-            event.message,
-            dagster_event=event,
-            pipeline_name=step_context.pipeline_name,
+        step_context.log.log_dagster_event(
+            level=logging.DEBUG, msg=event.message or "", dagster_event=event
         )
 
         return event
@@ -1082,11 +1117,7 @@ class DagsterEvent(
             ),
         )
 
-        step_context.log.error(
-            str(error),
-            dagster_event=event,
-            pipeline_name=step_context.pipeline_name,
-        )
+        step_context.log.log_dagster_event(level=logging.ERROR, msg=str(error), dagster_event=event)
 
         return event
 
@@ -1105,14 +1136,12 @@ class DagsterEvent(
             logging_tags=step_context.logging_tags,
             message=(
                 'Skipped the execution of hook "{hook_name}". It did not meet its triggering '
-                'condition during the execution of solid "{solid_name}".'
+                'condition during the execution of "{solid_name}".'
             ).format(hook_name=hook_def.name, solid_name=step_context.solid.name),
         )
 
-        step_context.log.debug(
-            event.message,
-            dagster_event=event,
-            pipeline_name=step_context.pipeline_name,
+        step_context.log.log_dagster_event(
+            level=logging.DEBUG, msg=event.message or "", dagster_event=event
         )
 
         return event
@@ -1121,7 +1150,7 @@ class DagsterEvent(
     def capture_logs(pipeline_context: IPlanContext, log_key: str, steps: List["ExecutionStep"]):
         step_keys = [step.key for step in steps]
         if len(step_keys) == 1:
-            message = f"Started capturing logs for solid: {step_keys[0]}."
+            message = f"Started capturing logs for step: {step_keys[0]}."
         else:
             message = f"Started capturing logs in process (pid: {os.getpid()})."
 
@@ -1163,6 +1192,19 @@ def get_step_output_event(
     return None
 
 
+@whitelist_for_serdes
+class AssetObservationData(
+    NamedTuple("_AssetObservation", [("asset_observation", AssetObservation)])
+):
+    def __new__(cls, asset_observation: AssetObservation):
+        return super(AssetObservationData, cls).__new__(
+            cls,
+            asset_observation=check.inst_param(
+                asset_observation, "asset_observation", AssetObservation
+            ),
+        )
+
+
 @whitelist_for_serdes
 class StepMaterializationData(
     NamedTuple(
@@ -1212,7 +1254,7 @@ class ObjectStoreOperationResultData(
     NamedTuple(
         "_ObjectStoreOperationResultData",
         [
-            ("op", str),
+            ("op", ObjectStoreOperationType),
             ("value_name", Optional[str]),
             ("metadata_entries", List[EventMetadataEntry]),
             ("address", Optional[str]),
@@ -1223,7 +1265,7 @@ class ObjectStoreOperationResultData(
 ):
     def __new__(
         cls,
-        op: str,
+        op: ObjectStoreOperationType,
         value_name: Optional[str] = None,
         metadata_entries: Optional[List[EventMetadataEntry]] = None,
         address: Optional[str] = None,
@@ -1232,7 +1274,7 @@ class ObjectStoreOperationResultData(
     ):
         return super(ObjectStoreOperationResultData, cls).__new__(
             cls,
-            op=check.str_param(op, "op"),
+            op=cast(ObjectStoreOperationType, check.str_param(op, "op")),
             value_name=check.opt_str_param(value_name, "value_name"),
             metadata_entries=check.opt_list_param(
                 metadata_entries, "metadata_entries", of_type=EventMetadataEntry
