@@ -17,6 +17,7 @@ from dagster.core.definitions import (
     GraphDefinition,
     IPipeline,
     InputDefinition,
+    JobDefinition,
     Node,
     NodeHandle,
     SolidDefinition,
@@ -24,9 +25,9 @@ from dagster.core.definitions import (
 )
 from dagster.core.definitions.composition import MappedInputPlaceholder
 from dagster.core.definitions.dependency import DependencyStructure
-from dagster.core.definitions.executor import ExecutorRequirement
+from dagster.core.definitions.executor_definition import ExecutorRequirement
 from dagster.core.definitions.mode import ModeDefinition
-from dagster.core.definitions.pipeline import PipelineDefinition
+from dagster.core.definitions.pipeline_definition import PipelineDefinition
 from dagster.core.errors import (
     DagsterExecutionStepNotFoundError,
     DagsterInvariantViolationError,
@@ -38,7 +39,7 @@ from dagster.core.execution.plan.handle import (
     UnresolvedStepHandle,
 )
 from dagster.core.execution.retries import RetryMode, RetryState
-from dagster.core.instance import DagsterInstance
+from dagster.core.instance import DagsterInstance, InstanceRef
 from dagster.core.storage.mem_io_manager import mem_io_manager
 from dagster.core.system_config.objects import ResolvedRunConfig
 from dagster.core.types.dagster_type import DagsterTypeKind
@@ -53,6 +54,7 @@ from .inputs import (
     FromDynamicCollect,
     FromMultipleSources,
     FromPendingDynamicStepOutput,
+    FromRootInputConfig,
     FromRootInputManager,
     FromStepOutput,
     FromUnresolvedStepOutput,
@@ -62,7 +64,7 @@ from .inputs import (
     UnresolvedMappedStepInput,
 )
 from .outputs import StepOutput, StepOutputHandle, UnresolvedStepOutputHandle
-from .state import KnownExecutionState
+from .state import KnownExecutionState, StepOutputVersionData
 from .step import (
     ExecutionStep,
     IExecutionStep,
@@ -98,7 +100,7 @@ class _PlanBuilder:
         resolved_run_config: ResolvedRunConfig,
         step_keys_to_execute: Optional[List[str]],
         known_state,
-        instance: Optional[DagsterInstance],
+        instance_ref: Optional[InstanceRef],
         tags: Dict[str, str],
     ):
         self.pipeline = check.inst_param(pipeline, "pipeline", IPipeline)
@@ -117,7 +119,7 @@ class _PlanBuilder:
             SolidOutputHandle, Union[StepOutputHandle, UnresolvedStepOutputHandle]
         ] = dict()
         self.known_state = known_state
-        self._instance = instance
+        self._instance_ref = instance_ref
         self._seen_handles: Set[StepHandleUnion] = set()
         self._tags = check.dict_param(tags, "tags", key_type=str, value_type=str)
 
@@ -157,7 +159,6 @@ class _PlanBuilder:
     def build(self) -> "ExecutionPlan":
         """Builds the execution plan"""
 
-        _check_io_manager_intermediate_storage(self.mode_definition, self.resolved_run_config)
         _check_persistent_storage_requirement(
             self.pipeline,
             self.mode_definition,
@@ -165,21 +166,52 @@ class _PlanBuilder:
         )
 
         pipeline_def = self.pipeline.get_definition()
+        root_inputs: List[
+            Union[StepInput, UnresolvedMappedStepInput, UnresolvedCollectStepInput]
+        ] = []
         # Recursively build the execution plan starting at the root pipeline
+        for input_def in pipeline_def.graph.input_defs:
+            input_name = input_def.name
+
+            input_source = get_root_graph_input_source(
+                plan_builder=self,
+                input_name=input_name,
+                input_def=input_def,
+            )
+
+            # If an input with dagster_type "Nothing" doesn't have a value
+            # we don't create a StepInput
+            if input_source is None:
+                continue
+
+            root_inputs.append(
+                StepInput(
+                    name=input_name,
+                    dagster_type_key=input_def.dagster_type.key,
+                    source=input_source,
+                )
+            )
+
         self._build_from_sorted_solids(
             pipeline_def.solids_in_topological_order,
             pipeline_def.dependency_structure,
+            parent_step_inputs=root_inputs,
         )
 
         step_dict = {step.handle: step for step in self._steps.values()}
+        step_dict_by_key = {step.key: step for step in self._steps.values()}
         step_handles_to_execute = [step.handle for step in self._steps.values()]
 
         executable_map, resolvable_map = _compute_step_maps(
             step_dict,
+            step_dict_by_key,
             step_handles_to_execute,
             self.known_state,
         )
 
+        executor_name = self.resolved_run_config.execution.execution_engine_name
+        step_output_versions = self.known_state.step_output_versions if self.known_state else []
+
         plan = ExecutionPlan(
             step_dict,
             executable_map,
@@ -188,11 +220,13 @@ class _PlanBuilder:
             self.known_state,
             _compute_artifacts_persisted(
                 step_dict,
+                step_dict_by_key,
                 step_handles_to_execute,
                 pipeline_def,
                 self.resolved_run_config,
                 executable_map,
             ),
+            executor_name=executor_name,
         )
 
         if self.step_keys_to_execute is not None:
@@ -202,12 +236,18 @@ class _PlanBuilder:
 
         # Expects that if step_keys_to_execute was set, that the `plan` variable will have the
         # reflected step_keys_to_execute
-        if pipeline_def.is_using_memoization(self._tags):
+        if pipeline_def.is_using_memoization(self._tags) and len(step_output_versions) == 0:
             if self.step_keys_to_execute is not None:
                 raise DagsterInvariantViolationError(
                     "Cannot use both memoization and re-execution at this time."
                 )
-            plan = plan.build_memoized_plan(pipeline_def, self.resolved_run_config, self._instance)
+            if self._instance_ref is None:
+                raise DagsterInvariantViolationError(
+                    "Attempted to build memoized execution plan without providing a persistent"
+                    "DagsterInstance to create_execution_plan."
+                )
+            instance = DagsterInstance.from_ref(self._instance_ref)
+            plan = plan.build_memoized_plan(pipeline_def, self.resolved_run_config, instance)
 
         return plan
 
@@ -362,6 +402,32 @@ class _PlanBuilder:
                 self.set_output_handle(output_handle, step_output_handle)
 
 
+def get_root_graph_input_source(
+    plan_builder: _PlanBuilder,
+    input_name: str,
+    input_def: InputDefinition,
+) -> Optional[FromRootInputConfig]:
+
+    input_config = plan_builder.resolved_run_config.inputs
+
+    if input_config and input_name in input_config:
+        return FromRootInputConfig(input_name=input_name)
+
+    if input_def.dagster_type.kind == DagsterTypeKind.NOTHING:
+        return None
+
+    # Otherwise we throw an error.
+    raise DagsterInvariantViolationError(
+        (
+            "In top-level graph of {described_target}, input {input_name} "
+            "must get a value from the inputs section of its configuration."
+        ).format(
+            described_target=plan_builder.pipeline.get_definition().describe_target(),
+            input_name=input_name,
+        )
+    )
+
+
 def get_step_input_source(
     plan_builder: _PlanBuilder,
     solid: Node,
@@ -515,11 +581,13 @@ def get_step_input_source(
     # Otherwise we throw an error.
     raise DagsterInvariantViolationError(
         (
-            "In pipeline {pipeline_name} solid {solid_name}, input {input_name} "
+            "In {described_target} {described_node}, input {input_name} "
             "must get a value either (a) from a dependency or (b) from the "
             "inputs section of its configuration."
         ).format(
-            pipeline_name=plan_builder.pipeline_name, solid_name=solid.name, input_name=input_name
+            described_target=plan_builder.pipeline.get_definition().describe_target(),
+            described_node=solid.describe_node(),
+            input_name=input_name,
         )
     )
 
@@ -534,7 +602,8 @@ class ExecutionPlan(
             ("step_handles_to_execute", List[StepHandleUnion]),
             ("known_state", KnownExecutionState),
             ("artifacts_persisted", bool),
-            ("step_output_versions", Dict[StepOutputHandle, str]),
+            ("step_dict_by_key", Dict[str, IExecutionStep]),
+            ("executor_name", Optional[str]),
         ],
     )
 ):
@@ -546,7 +615,8 @@ class ExecutionPlan(
         step_handles_to_execute,
         known_state=None,
         artifacts_persisted=False,
-        step_output_versions=None,
+        step_dict_by_key=None,
+        executor_name=None,
     ):
         return super(ExecutionPlan, cls).__new__(
             cls,
@@ -569,32 +639,45 @@ class ExecutionPlan(
             ),
             known_state=check.opt_inst_param(known_state, "known_state", KnownExecutionState),
             artifacts_persisted=check.bool_param(artifacts_persisted, "artifacts_persisted"),
-            step_output_versions=check.opt_dict_param(
-                step_output_versions,
-                "step_output_versions",
-                key_type=StepOutputHandle,
-                value_type=str,
+            step_dict_by_key={step.key: step for step in step_dict.values()}
+            if step_dict_by_key is None
+            else check.dict_param(
+                step_dict_by_key,
+                "step_dict_by_key",
+                key_type=str,
+                value_type=(
+                    ExecutionStep,
+                    UnresolvedMappedExecutionStep,
+                    UnresolvedCollectExecutionStep,
+                ),
             ),
+            executor_name=check.opt_str_param(executor_name, "executor_name"),
         )
 
     @property
     def steps(self) -> List[IExecutionStep]:
         return list(self.step_dict.values())
 
+    @property
+    def step_output_versions(self) -> Dict[StepOutputHandle, str]:
+        return StepOutputVersionData.get_version_dict_from_list(
+            self.known_state.step_output_versions if self.known_state else []
+        )
+
     @property
     def step_keys_to_execute(self) -> List[str]:
         return [handle.to_key() for handle in self.step_handles_to_execute]
 
     def get_step_output(self, step_output_handle: StepOutputHandle) -> StepOutput:
         check.inst_param(step_output_handle, "step_output_handle", StepOutputHandle)
-        return _get_step_output(self.step_dict, step_output_handle)
+        return _get_step_output(self.step_dict_by_key, step_output_handle)
 
     def get_manager_key(
         self,
         step_output_handle: StepOutputHandle,
         pipeline_def: PipelineDefinition,
     ) -> str:
-        return _get_manager_key(self.step_dict, step_output_handle, pipeline_def)
+        return _get_manager_key(self.step_dict_by_key, step_output_handle, pipeline_def)
 
     def has_step(self, handle: StepHandleUnion) -> bool:
         check.inst_param(handle, "handle", StepHandleTypes)
@@ -605,7 +688,10 @@ class ExecutionPlan(
         return self.step_dict[handle]
 
     def get_step_by_key(self, key: str) -> IExecutionStep:
-        return _get_step_by_key(self.step_dict, key)
+        check.str_param(key, "key")
+        if not key in self.step_dict_by_key:
+            check.failed(f"plan has no step with key {key}")
+        return self.step_dict_by_key[key]
 
     def get_executable_step_by_key(self, key: str) -> ExecutionStep:
         step = self.get_step_by_key(key)
@@ -637,7 +723,7 @@ class ExecutionPlan(
 
     def get_steps_to_execute_by_level(self) -> List[List[ExecutionStep]]:
         return _get_steps_to_execute_by_level(
-            self.step_dict, self.step_handles_to_execute, self.executable_map
+            self.step_dict, self.step_dict_by_key, self.step_handles_to_execute, self.executable_map
         )
 
     def get_executable_step_deps(self) -> Dict[str, Set[str]]:
@@ -655,6 +741,7 @@ class ExecutionPlan(
 
         _update_from_resolved_dynamic_outputs(
             self.step_dict,
+            self.step_dict_by_key,
             self.executable_map,
             self.resolvable_map,
             self.step_handles_to_execute,
@@ -673,6 +760,9 @@ class ExecutionPlan(
         step_output_versions=None,
     ) -> "ExecutionPlan":
         check.list_param(step_keys_to_execute, "step_keys_to_execute", of_type=str)
+        step_output_versions = check.opt_dict_param(
+            step_output_versions, "step_output_versions", key_type=StepOutputHandle, value_type=str
+        )
         step_handles_to_execute = [StepHandle.parse_from_key(key) for key in step_keys_to_execute]
 
         bad_keys = []
@@ -688,24 +778,42 @@ class ExecutionPlan(
 
         executable_map, resolvable_map = _compute_step_maps(
             self.step_dict,
+            self.step_dict_by_key,
             step_handles_to_execute,
             self.known_state,
         )
 
+        # If step output versions were provided when constructing the subset plan, add them to the
+        # known state.
+        if len(step_output_versions) > 0:
+
+            known_state = KnownExecutionState(
+                previous_retry_attempts=self.known_state.previous_retry_attempts
+                if self.known_state
+                else {},
+                dynamic_mappings=self.known_state.dynamic_mappings if self.known_state else {},
+                step_output_versions=StepOutputVersionData.get_version_list_from_dict(
+                    step_output_versions
+                ),
+            )
+        else:
+            known_state = self.known_state
+
         return ExecutionPlan(
             self.step_dict,
             executable_map,
             resolvable_map,
             step_handles_to_execute,
-            self.known_state,
+            known_state,
             _compute_artifacts_persisted(
                 self.step_dict,
+                self.step_dict_by_key,
                 step_handles_to_execute,
                 pipeline_def,
                 resolved_run_config,
                 executable_map,
             ),
-            step_output_versions=step_output_versions,
+            executor_name=self.executor_name,
         )
 
     def get_version_for_step_output_handle(
@@ -717,7 +825,7 @@ class ExecutionPlan(
         self,
         pipeline_def: PipelineDefinition,
         resolved_run_config: ResolvedRunConfig,
-        instance: Optional[DagsterInstance],
+        instance: DagsterInstance,
     ) -> "ExecutionPlan":
         """
         Returns:
@@ -727,9 +835,6 @@ class ExecutionPlan(
         from ...storage.memoizable_io_manager import MemoizableIOManager
         from ..resources_init import get_dependencies, resolve_resource_dependencies
 
-        instance = check.opt_inst_param(
-            instance, "instance", DagsterInstance, default=DagsterInstance.get()
-        )
         mode = resolved_run_config.mode
         mode_def = pipeline_def.get_mode_definition(mode)
 
@@ -782,7 +887,7 @@ class ExecutionPlan(
                 io_manager = getattr(resources, io_manager_key)
                 if not isinstance(io_manager, MemoizableIOManager):
                     raise DagsterInvariantViolationError(
-                        f"Pipeline {pipeline_def.name} uses memoization, but IO manager "
+                        f"{pipeline_def.describe_target().capitalize()} uses memoization, but IO manager "
                         f"'{io_manager_key}' is not a MemoizableIOManager. In order to use "
                         "memoization, all io managers need to subclass MemoizableIOManager. "
                         "Learn more about MemoizableIOManagers here: "
@@ -821,6 +926,7 @@ class ExecutionPlan(
             retry_mode,
             self.known_state.get_retry_state() if self.known_state else RetryState(),
             sort_key_fn,
+            self.known_state.step_output_versions if self.known_state else [],
         )
 
     def step_handle_for_single_step_plans(
@@ -847,7 +953,7 @@ class ExecutionPlan(
         resolved_run_config: ResolvedRunConfig,
         step_keys_to_execute: Optional[List[str]] = None,
         known_state=None,
-        instance=None,
+        instance_ref=None,
         tags=None,
     ) -> "ExecutionPlan":
         """Here we build a new ExecutionPlan from a pipeline definition and the resolved run config.
@@ -869,7 +975,7 @@ class ExecutionPlan(
             resolved_run_config=resolved_run_config,
             step_keys_to_execute=step_keys_to_execute,
             known_state=known_state,
-            instance=instance,
+            instance_ref=instance_ref,
             tags=tags,
         )
 
@@ -916,6 +1022,7 @@ class ExecutionPlan(
             )
 
         step_dict = {}
+        step_dict_by_key = {}
 
         for step_snap in execution_plan_snapshot.steps:
             input_snaps = step_snap.inputs
@@ -963,6 +1070,7 @@ class ExecutionPlan(
                 raise Exception(f"Unexpected step kind {str(step_snap.kind)}")
 
             step_dict[step.handle] = step
+            step_dict_by_key[step.key] = step
 
         step_handles_to_execute = [
             StepHandle.parse_from_key(key) for key in execution_plan_snapshot.step_keys_to_execute
@@ -970,15 +1078,11 @@ class ExecutionPlan(
 
         executable_map, resolvable_map = _compute_step_maps(
             step_dict,
+            step_dict_by_key,
             step_handles_to_execute,
             execution_plan_snapshot.initial_known_state,
         )
 
-        step_output_versions: Dict[StepOutputHandle, str] = {}
-        for step_output_version_data in execution_plan_snapshot.step_output_versions:
-            step_output_handle = step_output_version_data.step_output_handle
-            step_output_versions[step_output_handle] = step_output_version_data.version
-
         return ExecutionPlan(
             step_dict,
             executable_map,
@@ -986,12 +1090,13 @@ class ExecutionPlan(
             step_handles_to_execute,
             execution_plan_snapshot.initial_known_state,
             execution_plan_snapshot.artifacts_persisted,
-            step_output_versions,
+            executor_name=execution_plan_snapshot.executor_name,
         )
 
 
 def _update_from_resolved_dynamic_outputs(
     step_dict: Dict[StepHandleUnion, IExecutionStep],
+    step_dict_by_key: Dict[str, IExecutionStep],
     executable_map: Dict[str, Union[StepHandle, ResolvedFromDynamicStepHandle]],
     resolvable_map: Dict[FrozenSet[str], List[UnresolvedStepHandle]],
     step_handles_to_execute: List[StepHandleUnion],
@@ -1023,6 +1128,7 @@ def _update_from_resolved_dynamic_outputs(
     for step in resolved_steps:
         step_dict[step.handle] = step
         executable_map[step.key] = step.handle
+        step_dict_by_key[step.key] = step
 
     for key_set in key_sets_to_clear:
         del resolvable_map[key_set]
@@ -1058,48 +1164,28 @@ def _check_persistent_storage_requirement(
 
     pipeline_def = pipeline.get_definition()
     executor_def = executor_def_from_config(mode_def, resolved_run_config)
-    if ExecutorRequirement.PERSISTENT_OUTPUTS not in executor_def.requirements:
+    requirements_lst = executor_def.get_requirements(
+        resolved_run_config.execution.execution_engine_config
+    )
+    if ExecutorRequirement.PERSISTENT_OUTPUTS not in requirements_lst:
         return
 
-    intermediate_storage_def = resolved_run_config.intermediate_storage_def_for_mode(mode_def)
-
-    if not (
-        can_isolate_steps(pipeline_def, mode_def)
-        or (intermediate_storage_def and intermediate_storage_def.is_persistent)
-    ):
-        raise DagsterUnmetExecutorRequirementsError(
-            "You have attempted to use an executor that uses multiple processes, but your pipeline "
-            "includes solid outputs that will not be stored somewhere where other processes can "
-            "retrieve them. Please use a persistent IO manager for these outputs. E.g. with\n"
-            '    @pipeline(mode_defs=[ModeDefinition(resource_defs={"io_manager": fs_io_manager})])'
-        )
-
-
-def _check_io_manager_intermediate_storage(
-    mode_def: ModeDefinition, resolved_run_config: ResolvedRunConfig
-) -> None:
-    """Only one of io_manager and intermediate_storage should be set."""
-    # pylint: disable=comparison-with-callable
-    from dagster.core.storage.system_storage import mem_intermediate_storage
-
-    intermediate_storage_def = resolved_run_config.intermediate_storage_def_for_mode(mode_def)
-    intermediate_storage_is_default = (
-        intermediate_storage_def is None or intermediate_storage_def == mem_intermediate_storage
-    )
-
-    io_manager = mode_def.resource_defs["io_manager"]
-    io_manager_is_default = io_manager == mem_io_manager
-
-    if not intermediate_storage_is_default and not io_manager_is_default:
-        raise DagsterInvariantViolationError(
-            'You have specified an intermediate storage, "{intermediate_storage_name}", and have '
-            "also specified a default IO manager. You must specify only one. To avoid specifying "
-            "an intermediate storage, omit the intermediate_storage_defs argument to your "
-            'ModeDefinition and omit "intermediate_storage" in your run config. To avoid '
-            'specifying a default IO manager, omit the "io_manager" key from the '
-            "resource_defs argument to your ModeDefinition.".format(
-                intermediate_storage_name=intermediate_storage_def.name
+    if not can_isolate_steps(pipeline_def, mode_def):
+        if isinstance(pipeline_def, JobDefinition):
+            target = "job"
+            node = "op"
+            suggestion = 'the_graph.to_job(resource_defs={"io_manager": fs_io_manager})'
+        else:
+            target = "pipeline"
+            node = "solid"
+            suggestion = (
+                '@pipeline(mode_defs=[ModeDefinition(resource_defs={"io_manager": fs_io_manager})])'
             )
+        raise DagsterUnmetExecutorRequirementsError(
+            f"You have attempted to use an executor that uses multiple processes, but your {target} "
+            f"includes {node} outputs that will not be stored somewhere where other processes can "
+            "retrieve them. Please use a persistent IO manager for these outputs. E.g. with\n"
+            f"    {suggestion}"
         )
 
 
@@ -1160,7 +1246,12 @@ def should_skip_step(execution_plan: ExecutionPlan, instance: DagsterInstance, r
 
 
 def _compute_artifacts_persisted(
-    step_dict, step_handles_to_execute, pipeline_def, resolved_run_config, executable_map
+    step_dict,
+    step_dict_by_key,
+    step_handles_to_execute,
+    pipeline_def,
+    resolved_run_config,
+    executable_map,
 ):
     """
     Check if all the border steps of the current run have non-in-memory IO managers for reexecution.
@@ -1169,21 +1260,13 @@ def _compute_artifacts_persisted(
     """
     # pylint: disable=comparison-with-callable
 
-    # intermediate storage backcomopat
-    # https://github.com/dagster-io/dagster/issues/3043
-
     mode_def = pipeline_def.get_mode_definition(resolved_run_config.mode)
 
-    if mode_def.get_intermediate_storage_def(
-        resolved_run_config.intermediate_storage.intermediate_storage_name
-    ).is_persistent:
-        return True
-
     if len(step_dict) == 0:
         return False
 
     steps_by_level = _get_steps_to_execute_by_level(
-        step_dict, step_handles_to_execute, executable_map
+        step_dict, step_dict_by_key, step_handles_to_execute, executable_map
     )
 
     if len(steps_by_level) == 0:
@@ -1193,7 +1276,9 @@ def _compute_artifacts_persisted(
         # check if all its inputs' upstream step outputs have non-in-memory IO manager configured
         for step_input in step.step_inputs:
             for step_output_handle in step_input.get_step_output_handle_dependencies():
-                io_manager_key = _get_manager_key(step_dict, step_output_handle, pipeline_def)
+                io_manager_key = _get_manager_key(
+                    step_dict_by_key, step_output_handle, pipeline_def
+                )
                 manager_def = mode_def.resource_defs.get(io_manager_key)
                 if (
                     # no IO manager is configured
@@ -1213,12 +1298,11 @@ def _get_step_by_key(step_dict, key) -> IExecutionStep:
     check.failed(f"plan has no step with key {key}")
 
 
-def _get_steps_to_execute_by_level(step_dict, step_handles_to_execute, executable_map):
+def _get_steps_to_execute_by_level(
+    step_dict, step_dict_by_key, step_handles_to_execute, executable_map
+):
     return [
-        [
-            cast(ExecutionStep, _get_step_by_key(step_dict, step_key))
-            for step_key in sorted(step_key_level)
-        ]
+        [cast(ExecutionStep, step_dict_by_key[step_key]) for step_key in sorted(step_key_level)]
         for step_key_level in toposort(
             _get_executable_step_deps(step_dict, step_handles_to_execute, executable_map)
         )
@@ -1258,14 +1342,14 @@ def _get_executable_step_deps(
     return deps
 
 
-def _get_step_output(step_dict, step_output_handle: StepOutputHandle) -> StepOutput:
+def _get_step_output(step_dict_by_key, step_output_handle: StepOutputHandle) -> StepOutput:
     check.inst_param(step_output_handle, "step_output_handle", StepOutputHandle)
-    step = _get_step_by_key(step_dict, step_output_handle.step_key)
+    step = step_dict_by_key[step_output_handle.step_key]
     return step.step_output_named(step_output_handle.output_name)
 
 
-def _get_manager_key(step_dict, step_output_handle, pipeline_def):
-    step_output = _get_step_output(step_dict, step_output_handle)
+def _get_manager_key(step_dict_by_key, step_output_handle, pipeline_def):
+    step_output = _get_step_output(step_dict_by_key, step_output_handle)
     solid_handle = step_output.solid_handle
     output_def = pipeline_def.get_solid(solid_handle).output_def_named(step_output.name)
     return output_def.io_manager_key
@@ -1273,7 +1357,7 @@ def _get_manager_key(step_dict, step_output_handle, pipeline_def):
 
 # computes executable_map and resolvable_map and returns them as a tuple. Also
 # may modify the passed in step_dict to include resolved step using known_state.
-def _compute_step_maps(step_dict, step_handles_to_execute, known_state):
+def _compute_step_maps(step_dict, step_dict_by_key, step_handles_to_execute, known_state):
     check.list_param(
         step_handles_to_execute,
         "step_handles_to_execute",
@@ -1305,7 +1389,7 @@ def _compute_step_maps(step_dict, step_handles_to_execute, known_state):
             for key in step.resolved_by_step_keys:
                 if key not in step_keys_to_execute:
                     raise DagsterInvariantViolationError(
-                        f'Unresolved ExecutionStep "{step.key}" is resolved by "{step.resolved_by_step_key}" '
+                        f'Unresolved ExecutionStep "{step.key}" is resolved by "{key}" '
                         "which is not part of the current step selection"
                     )
 
@@ -1318,6 +1402,7 @@ def _compute_step_maps(step_dict, step_handles_to_execute, known_state):
     if known_state:
         _update_from_resolved_dynamic_outputs(
             step_dict,
+            step_dict_by_key,
             executable_map,
             resolvable_map,
             step_handles_to_execute,
