@@ -1,13 +1,19 @@
 from collections import namedtuple
+from typing import Dict, List, NamedTuple, Optional
 
 from dagster import check
 from dagster.core.code_pointer import CodePointer
 from dagster.core.execution.plan.state import KnownExecutionState
 from dagster.core.execution.retries import RetryMode
-from dagster.core.host_representation import ExternalPipelineOrigin, ExternalRepositoryOrigin
+from dagster.core.host_representation.origin import (
+    ExternalPipelineOrigin,
+    ExternalRepositoryOrigin,
+    RepositoryLocationOrigin,
+)
 from dagster.core.instance.ref import InstanceRef
-from dagster.core.origin import PipelinePythonOrigin
-from dagster.serdes import whitelist_for_serdes
+from dagster.core.origin import PipelinePythonOrigin, get_python_environment_entry_point
+from dagster.serdes import serialize_dagster_namedtuple, whitelist_for_serdes
+from dagster.utils import frozenlist
 from dagster.utils.error import SerializableErrorInfo
 
 
@@ -15,7 +21,8 @@ from dagster.utils.error import SerializableErrorInfo
 class ExecutionPlanSnapshotArgs(
     namedtuple(
         "_ExecutionPlanSnapshotArgs",
-        "pipeline_origin solid_selection run_config mode step_keys_to_execute pipeline_snapshot_id known_state",
+        "pipeline_origin solid_selection run_config mode step_keys_to_execute pipeline_snapshot_id "
+        "known_state instance_ref",
     )
 ):
     def __new__(
@@ -27,6 +34,7 @@ class ExecutionPlanSnapshotArgs(
         step_keys_to_execute,
         pipeline_snapshot_id,
         known_state=None,
+        instance_ref=None,
     ):
         return super(ExecutionPlanSnapshotArgs, cls).__new__(
             cls,
@@ -41,9 +49,18 @@ class ExecutionPlanSnapshotArgs(
             ),
             pipeline_snapshot_id=check.str_param(pipeline_snapshot_id, "pipeline_snapshot_id"),
             known_state=check.opt_inst_param(known_state, "known_state", KnownExecutionState),
+            instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
         )
 
 
+def _get_entry_point(origin: PipelinePythonOrigin):
+    return (
+        origin.repository_origin.entry_point
+        if origin.repository_origin.entry_point
+        else get_python_environment_entry_point(origin.executable_path)
+    )
+
+
 @whitelist_for_serdes
 class ExecuteRunArgs(namedtuple("_ExecuteRunArgs", "pipeline_origin pipeline_run_id instance_ref")):
     def __new__(cls, pipeline_origin, pipeline_run_id, instance_ref):
@@ -58,6 +75,35 @@ class ExecuteRunArgs(namedtuple("_ExecuteRunArgs", "pipeline_origin pipeline_run
             instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
         )
 
+    def get_command_args(self) -> List[str]:
+        return _get_entry_point(self.pipeline_origin) + [
+            "api",
+            "execute_run",
+            serialize_dagster_namedtuple(self),
+        ]
+
+
+@whitelist_for_serdes
+class ResumeRunArgs(namedtuple("_ResumeRunArgs", "pipeline_origin pipeline_run_id instance_ref")):
+    def __new__(cls, pipeline_origin, pipeline_run_id, instance_ref):
+        return super(ResumeRunArgs, cls).__new__(
+            cls,
+            pipeline_origin=check.inst_param(
+                pipeline_origin,
+                "pipeline_origin",
+                PipelinePythonOrigin,
+            ),
+            pipeline_run_id=check.str_param(pipeline_run_id, "pipeline_run_id"),
+            instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
+        )
+
+    def get_command_args(self) -> List[str]:
+        return _get_entry_point(self.pipeline_origin) + [
+            "api",
+            "resume_run",
+            serialize_dagster_namedtuple(self),
+        ]
+
 
 @whitelist_for_serdes
 class ExecuteExternalPipelineArgs(
@@ -111,6 +157,13 @@ class ExecuteStepArgs(
             ),
         )
 
+    def get_command_args(self) -> List[str]:
+        return _get_entry_point(self.pipeline_origin) + [
+            "api",
+            "execute_step",
+            serialize_dagster_namedtuple(self),
+        ]
+
 
 @whitelist_for_serdes
 class LoadableRepositorySymbol(
@@ -126,9 +179,14 @@ class LoadableRepositorySymbol(
 
 @whitelist_for_serdes
 class ListRepositoriesResponse(
-    namedtuple(
+    NamedTuple(
         "_ListRepositoriesResponse",
-        "repository_symbols executable_path repository_code_pointer_dict",
+        [
+            ("repository_symbols", List[LoadableRepositorySymbol]),
+            ("executable_path", Optional[str]),
+            ("repository_code_pointer_dict", Dict[str, CodePointer]),
+            ("entry_point", Optional[List[str]]),
+        ],
     )
 ):
     def __new__(
@@ -136,14 +194,13 @@ class ListRepositoriesResponse(
         repository_symbols,
         executable_path=None,
         repository_code_pointer_dict=None,
+        entry_point=None,
     ):
         return super(ListRepositoriesResponse, cls).__new__(
             cls,
             repository_symbols=check.list_param(
                 repository_symbols, "repository_symbols", of_type=LoadableRepositorySymbol
             ),
-            # These are currently only used by the GRPC Repository Location, but
-            # we will need to migrate the rest of the repository locations to use this.
             executable_path=check.opt_str_param(executable_path, "executable_path"),
             repository_code_pointer_dict=check.opt_dict_param(
                 repository_code_pointer_dict,
@@ -151,6 +208,11 @@ class ListRepositoriesResponse(
                 key_type=str,
                 value_type=CodePointer,
             ),
+            entry_point=(
+                frozenlist(check.list_param(entry_point, "entry_point", of_type=str))
+                if entry_point != None
+                else None
+            ),
         )
 
 
@@ -233,6 +295,18 @@ class PipelineSubsetSnapshotArgs(
         )
 
 
+@whitelist_for_serdes
+class NotebookPathArgs(namedtuple("_NotebookPathArgs", "repository_location_origin notebook_path")):
+    def __new__(cls, repository_location_origin, notebook_path):
+        return super(NotebookPathArgs, cls).__new__(
+            cls,
+            repository_location_origin=check.inst_param(
+                repository_location_origin, "repository_location_origin", RepositoryLocationOrigin
+            ),
+            notebook_path=check.str_param(notebook_path, "notebook_path"),
+        )
+
+
 @whitelist_for_serdes
 class ExternalScheduleExecutionArgs(
     namedtuple(
@@ -254,7 +328,7 @@ class ExternalScheduleExecutionArgs(
             repository_origin=check.inst_param(
                 repository_origin, "repository_origin", ExternalRepositoryOrigin
             ),
-            instance_ref=check.inst_param(instance_ref, "instance_ref", InstanceRef),
+            instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
             schedule_name=check.str_param(schedule_name, "schedule_name"),
             scheduled_execution_timestamp=check.opt_float_param(
                 scheduled_execution_timestamp, "scheduled_execution_timestamp"
@@ -270,23 +344,30 @@ class ExternalScheduleExecutionArgs(
 class SensorExecutionArgs(
     namedtuple(
         "_SensorExecutionArgs",
-        "repository_origin instance_ref sensor_name last_completion_time last_run_key",
+        "repository_origin instance_ref sensor_name last_completion_time last_run_key cursor",
     )
 ):
     def __new__(
-        cls, repository_origin, instance_ref, sensor_name, last_completion_time, last_run_key
+        cls,
+        repository_origin,
+        instance_ref,
+        sensor_name,
+        last_completion_time,
+        last_run_key,
+        cursor,
     ):
         return super(SensorExecutionArgs, cls).__new__(
             cls,
             repository_origin=check.inst_param(
                 repository_origin, "repository_origin", ExternalRepositoryOrigin
             ),
-            instance_ref=check.inst_param(instance_ref, "instance_ref", InstanceRef),
+            instance_ref=check.opt_inst_param(instance_ref, "instance_ref", InstanceRef),
             sensor_name=check.str_param(sensor_name, "sensor_name"),
             last_completion_time=check.opt_float_param(
                 last_completion_time, "last_completion_time"
             ),
             last_run_key=check.opt_str_param(last_run_key, "last_run_key"),
+            cursor=check.opt_str_param(cursor, "cursor"),
         )
 
 
