@@ -1,4 +1,3 @@
-import json
 import os
 import string
 import sys
@@ -9,32 +8,40 @@ import mock
 import pytest
 from click.testing import CliRunner
 from dagster import (
+    ModeDefinition,
+    Out,
+    Output,
     Partition,
     PartitionSetDefinition,
     PresetDefinition,
     ScheduleDefinition,
+    String,
     execute_pipeline,
+    graph,
+    in_process_executor,
+    job,
     lambda_solid,
+    op,
     pipeline,
     repository,
     solid,
 )
 from dagster.cli import ENV_PREFIX, cli
+from dagster.cli.job import job_execute_command
 from dagster.cli.pipeline import pipeline_execute_command
 from dagster.cli.run import run_delete_command, run_list_command, run_wipe_command
 from dagster.core.definitions.decorators.sensor import sensor
-from dagster.core.definitions.sensor import RunRequest
-from dagster.core.test_utils import instance_for_test, instance_for_test_tempdir
+from dagster.core.definitions.partition import PartitionedConfig, StaticPartitionsDefinition
+from dagster.core.definitions.sensor_definition import RunRequest
+from dagster.core.storage.memoizable_io_manager import versioned_filesystem_io_manager
+from dagster.core.storage.tags import MEMOIZED_RUN_TAG
+from dagster.core.test_utils import instance_for_test
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster.grpc.server import GrpcServerProcess
 from dagster.utils import file_relative_path, merge_dicts
 from dagster.version import __version__
 
 
-def no_print(_):
-    return None
-
-
 @lambda_solid
 def do_something():
     return 1
@@ -59,6 +66,39 @@ def define_foo_pipeline():
     return foo_pipeline
 
 
+@op
+def do_something_op():
+    return 1
+
+
+@op
+def do_input_op(x):
+    return x
+
+
+@graph()
+def qux():
+    do_input_op(do_something_op())
+
+
+qux_job = qux.to_job(
+    config=PartitionedConfig(
+        partitions_def=StaticPartitionsDefinition(["abc"]), run_config_for_partition_fn=lambda _: {}
+    ),
+    tags={"foo": "bar"},
+    executor_def=in_process_executor,
+)
+
+
+@job(executor_def=in_process_executor)
+def quux_job():
+    do_something_op()
+
+
+def define_qux_job():
+    return qux_job
+
+
 @pipeline(name="baz", description="Not much tbh")
 def baz_pipeline():
     do_input()
@@ -86,7 +126,7 @@ def define_bar_schedules():
         "foo_schedule": ScheduleDefinition(
             "foo_schedule",
             cron_schedule="* * * * *",
-            pipeline_name="test_pipeline",
+            pipeline_name="foo",
             run_config={},
         ),
         "partitioned_schedule": partition_set.create_schedule_definition(
@@ -137,6 +177,20 @@ def define_bar_sensors():
     return {"foo_sensor": foo_sensor}
 
 
+@solid(version="foo")
+def my_solid():
+    return 5
+
+
+@pipeline(
+    name="memoizable",
+    mode_defs=[ModeDefinition(resource_defs={"io_manager": versioned_filesystem_io_manager})],
+    tags={MEMOIZED_RUN_TAG: "true"},
+)
+def memoizable_pipeline():
+    my_solid()
+
+
 @repository
 def bar():
     return {
@@ -144,7 +198,9 @@ def bar():
             "foo": foo_pipeline,
             "baz": baz_pipeline,
             "partitioned_scheduled_pipeline": partitioned_scheduled_pipeline,
+            "memoizable": memoizable_pipeline,
         },
+        "jobs": {"qux": qux_job, "quux": quux_job},
         "schedules": define_bar_schedules(),
         "partition_sets": define_bar_partitions(),
         "sensors": define_bar_sensors(),
@@ -171,6 +227,48 @@ def stderr_pipeline():
     fail()
 
 
+@op
+def spew_op(context):
+    context.log.info("SPEW OP")
+
+
+@op
+def fail_op(context):
+    raise Exception("FAILURE OP")
+
+
+@graph()
+def my_stdout():
+    spew_op()
+
+
+@graph()
+def my_stderr():
+    fail_op()
+
+
+@op(out={"out_1": Out(String), "out_2": Out(String)})
+def root():
+    yield Output("foo", "out_1")
+    yield Output("bar", "out_2")
+
+
+@op
+def branch_op(_value):
+    pass
+
+
+@graph()
+def multiproc():
+    out_1, out_2 = root()
+    branch_op(out_1)
+    branch_op(out_2)
+
+
+# default executor_def is multiproc
+multiproc_job = multiproc.to_job()
+
+
 @contextmanager
 def _default_cli_test_instance_tempdir(temp_dir, overrides=None):
     default_overrides = {
@@ -179,8 +277,9 @@ def _default_cli_test_instance_tempdir(temp_dir, overrides=None):
             "class": "MockedRunLauncher",
         }
     }
-    with instance_for_test_tempdir(
-        temp_dir, overrides=merge_dicts(default_overrides, (overrides if overrides else {}))
+    with instance_for_test(
+        temp_dir=temp_dir,
+        overrides=merge_dicts(default_overrides, (overrides if overrides else {})),
     ) as instance:
         with mock.patch("dagster.core.instance.DagsterInstance.get") as _instance:
             _instance.return_value = instance
@@ -216,7 +315,7 @@ def grpc_server_bar_kwargs(pipeline_name=None):
     with server_process.create_ephemeral_client() as client:
         args = {"grpc_host": client.host}
         if pipeline_name:
-            args["pipeline"] = "foo"
+            args["pipeline_or_job"] = "foo"
         if client.port:
             args["grpc_port"] = client.port
         if client.socket:
@@ -226,21 +325,21 @@ def grpc_server_bar_kwargs(pipeline_name=None):
 
 
 @contextmanager
-def python_bar_cli_args(pipeline_name=None):
+def python_bar_cli_args(pipeline_or_job_name=None, using_job_op_graph_apis=False):
     args = [
         "-m",
         "dagster_tests.cli_tests.command_tests.test_cli_commands",
         "-a",
         "bar",
     ]
-    if pipeline_name:
-        args.append("-p")
-        args.append(pipeline_name)
+    if pipeline_or_job_name:
+        args.append("-j" if using_job_op_graph_apis else "-p")
+        args.append(pipeline_or_job_name)
     yield args
 
 
 @contextmanager
-def grpc_server_bar_cli_args(pipeline_name=None):
+def grpc_server_bar_cli_args(pipeline_name=None, using_job_op_graph_apis=False):
     server_process = GrpcServerProcess(
         loadable_target_origin=LoadableTargetOrigin(
             executable_path=sys.executable,
@@ -257,7 +356,7 @@ def grpc_server_bar_cli_args(pipeline_name=None):
             args.append("--grpc-socket")
             args.append(client.socket)
         if pipeline_name:
-            args.append("--pipeline")
+            args.append("--job" if using_job_op_graph_apis else "--pipeline")
             args.append(pipeline_name)
 
         yield args
@@ -279,10 +378,10 @@ def launch_command_contexts():
     yield pytest.param(grpc_server_bar_pipeline_args())
 
 
-def pipeline_python_origin_contexts():
+def pipeline_or_job_python_origin_contexts(using_job_op_graph_apis=False):
     return [
-        args_with_default_cli_test_instance(pipeline_target_args)
-        for pipeline_target_args in valid_pipeline_python_origin_target_args()
+        args_with_default_cli_test_instance(target_args)
+        for target_args in valid_pipeline_or_job_python_origin_target_args(using_job_op_graph_apis)
     ]
 
 
@@ -356,25 +455,30 @@ def grpc_server_backfill_args():
 def non_existant_python_origin_target_args():
     return {
         "workspace": None,
-        "pipeline": "foo",
+        "pipeline_or_job": "foo",
         "python_file": file_relative_path(__file__, "made_up_file.py"),
         "module_name": None,
         "attribute": "bar",
     }
 
 
-def valid_pipeline_python_origin_target_args():
+def valid_pipeline_or_job_python_origin_target_args(using_job_op_graph_apis=False):
+    pipeline_or_job_name = "qux" if using_job_op_graph_apis else "foo"
+    pipeline_or_job_fn_name = "qux_job" if using_job_op_graph_apis else "foo_pipeline"
+    pipeline_or_job_def_name = (
+        "define_qux_job" if using_job_op_graph_apis else "define_foo_pipeline"
+    )
     return [
         {
             "workspace": None,
-            "pipeline": "foo",
+            "pipeline_or_job": pipeline_or_job_name,
             "python_file": file_relative_path(__file__, "test_cli_commands.py"),
             "module_name": None,
             "attribute": "bar",
         },
         {
             "workspace": None,
-            "pipeline": "foo",
+            "pipeline_or_job": pipeline_or_job_name,
             "python_file": file_relative_path(__file__, "test_cli_commands.py"),
             "module_name": None,
             "attribute": "bar",
@@ -382,53 +486,69 @@ def valid_pipeline_python_origin_target_args():
         },
         {
             "workspace": None,
-            "pipeline": "foo",
+            "pipeline_or_job": pipeline_or_job_name,
             "python_file": None,
             "module_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
             "attribute": "bar",
         },
         {
             "workspace": None,
-            "pipeline": "foo",
-            "python_file": None,
-            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
-            "attribute": "bar",
-        },
-        {
-            "workspace": None,
-            "pipeline": None,
+            "pipeline_or_job": pipeline_or_job_name,
             "python_file": None,
             "module_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
-            "attribute": "foo_pipeline",
-        },
-        {
-            "workspace": None,
-            "pipeline": None,
-            "python_file": None,
-            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
-            "attribute": "foo_pipeline",
-        },
-        {
-            "workspace": None,
-            "pipeline": None,
-            "python_file": file_relative_path(__file__, "test_cli_commands.py"),
-            "module_name": None,
-            "attribute": "define_foo_pipeline",
-        },
-        {
-            "workspace": None,
-            "pipeline": None,
-            "python_file": file_relative_path(__file__, "test_cli_commands.py"),
-            "module_name": None,
-            "attribute": "define_foo_pipeline",
+            "attribute": "bar",
             "working_directory": os.path.dirname(__file__),
         },
         {
             "workspace": None,
-            "pipeline": None,
+            "pipeline_or_job": pipeline_or_job_name,
+            "python_file": None,
+            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "attribute": "bar",
+        },
+        {
+            "workspace": None,
+            "pipeline_or_job": pipeline_or_job_name,
+            "python_file": None,
+            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "attribute": "bar",
+            "working_directory": os.path.dirname(__file__),
+        },
+        {
+            "workspace": None,
+            "pipeline_or_job": None,
+            "python_file": None,
+            "module_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "attribute": pipeline_or_job_fn_name,
+        },
+        {
+            "workspace": None,
+            "pipeline_or_job": None,
+            "python_file": None,
+            "package_name": "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "attribute": pipeline_or_job_fn_name,
+        },
+        {
+            "workspace": None,
+            "pipeline_or_job": None,
             "python_file": file_relative_path(__file__, "test_cli_commands.py"),
             "module_name": None,
-            "attribute": "foo_pipeline",
+            "attribute": pipeline_or_job_def_name,
+        },
+        {
+            "workspace": None,
+            "pipeline_or_job": None,
+            "python_file": file_relative_path(__file__, "test_cli_commands.py"),
+            "module_name": None,
+            "attribute": pipeline_or_job_def_name,
+            "working_directory": os.path.dirname(__file__),
+        },
+        {
+            "workspace": None,
+            "pipeline_or_job": None,
+            "python_file": file_relative_path(__file__, "test_cli_commands.py"),
+            "module_name": None,
+            "attribute": pipeline_or_job_fn_name,
         },
     ]
 
@@ -437,19 +557,19 @@ def valid_external_pipeline_target_args():
     return [
         {
             "workspace": (file_relative_path(__file__, "repository_file.yaml"),),
-            "pipeline": "foo",
+            "pipeline_or_job": "foo",
             "python_file": None,
             "module_name": None,
             "attribute": None,
         },
         {
             "workspace": (file_relative_path(__file__, "repository_module.yaml"),),
-            "pipeline": "foo",
+            "pipeline_or_job": "foo",
             "python_file": None,
             "module_name": None,
             "attribute": None,
         },
-    ] + [args for args in valid_pipeline_python_origin_target_args()]
+    ] + [args for args in valid_pipeline_or_job_python_origin_target_args()]
 
 
 def valid_pipeline_python_origin_target_cli_args():
@@ -491,6 +611,55 @@ def valid_pipeline_python_origin_target_cli_args():
     ]
 
 
+def valid_job_python_origin_target_cli_args():
+    return [
+        ["-f", file_relative_path(__file__, "test_cli_commands.py"), "-a", "bar", "-j", "qux"],
+        [
+            "-f",
+            file_relative_path(__file__, "test_cli_commands.py"),
+            "-d",
+            os.path.dirname(__file__),
+            "-a",
+            "bar",
+            "-j",
+            "qux",
+        ],
+        [
+            "-m",
+            "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "-a",
+            "bar",
+            "-j",
+            "qux",
+        ],
+        [
+            "-m",
+            "dagster_tests.cli_tests.command_tests.test_cli_commands",
+            "-a",
+            "bar",
+            "-d",
+            os.path.dirname(__file__),
+            "-j",
+            "qux",
+        ],
+        ["-m", "dagster_tests.cli_tests.command_tests.test_cli_commands", "-j", "qux"],
+        [
+            "-f",
+            file_relative_path(__file__, "test_cli_commands.py"),
+            "-a",
+            "define_qux_job",
+        ],
+        [
+            "-f",
+            file_relative_path(__file__, "test_cli_commands.py"),
+            "-d",
+            os.path.dirname(__file__),
+            "-a",
+            "define_qux_job",
+        ],
+    ]
+
+
 def valid_external_pipeline_target_cli_args_no_preset():
     return [
         ["-w", file_relative_path(__file__, "repository_file.yaml"), "-p", "foo"],
@@ -507,8 +676,23 @@ def valid_external_pipeline_target_cli_args_no_preset():
     ] + [args for args in valid_pipeline_python_origin_target_cli_args()]
 
 
+def valid_external_job_target_cli_args():
+    return [
+        ["-w", file_relative_path(__file__, "repository_file.yaml"), "-j", "qux"],
+        ["-w", file_relative_path(__file__, "repository_module.yaml"), "-j", "qux"],
+        ["-w", file_relative_path(__file__, "workspace.yaml"), "-j", "qux"],
+        [
+            "-w",
+            file_relative_path(__file__, "override.yaml"),
+            "-w",
+            file_relative_path(__file__, "workspace.yaml"),
+            "-j",
+            "qux",
+        ],
+    ] + [args for args in valid_job_python_origin_target_cli_args()]
+
+
 def valid_external_pipeline_target_cli_args_with_preset():
-    run_config = {"storage": {"filesystem": {"config": {"base_dir": "/tmp"}}}}
     return valid_external_pipeline_target_cli_args_no_preset() + [
         [
             "-f",
@@ -527,8 +711,6 @@ def valid_external_pipeline_target_cli_args_with_preset():
             os.path.dirname(__file__),
             "-a",
             "define_foo_pipeline",
-            "--config-json",
-            json.dumps(run_config),
         ],
     ]
 
@@ -548,12 +730,21 @@ def test_run_wipe_correct_delete_message():
         assert result.exit_code == 0
 
 
+@pytest.mark.parametrize("force_flag", ["--force", "-f"])
+def test_run_wipe_force(force_flag):
+    with instance_for_test():
+        runner = CliRunner()
+        result = runner.invoke(run_wipe_command, args=[force_flag])
+        assert "Deleted all run history and event logs" in result.output
+        assert result.exit_code == 0
+
+
 def test_run_wipe_incorrect_delete_message():
     with instance_for_test():
         runner = CliRunner()
         result = runner.invoke(run_wipe_command, input="WRONG\n")
         assert "Exiting without deleting all run history and event logs" in result.output
-        assert result.exit_code == 0
+        assert result.exit_code == 1
 
 
 def test_run_delete_bad_id():
@@ -561,7 +752,7 @@ def test_run_delete_bad_id():
         runner = CliRunner()
         result = runner.invoke(run_delete_command, args=["1234"], input="DELETE\n")
         assert "No run found with id 1234" in result.output
-        assert result.exit_code == 0
+        assert result.exit_code == 1
 
 
 def test_run_delete_correct_delete_message():
@@ -573,20 +764,30 @@ def test_run_delete_correct_delete_message():
         assert result.exit_code == 0
 
 
+@pytest.mark.parametrize("force_flag", ["--force", "-f"])
+def test_run_delete_force(force_flag):
+    with instance_for_test() as instance:
+        run_id = execute_pipeline(foo_pipeline, instance=instance).run_id
+        runner = CliRunner()
+        result = runner.invoke(run_delete_command, args=[force_flag, run_id])
+        assert "Deleted run" in result.output
+        assert result.exit_code == 0
+
+
 def test_run_delete_incorrect_delete_message():
     with instance_for_test() as instance:
         pipeline_result = execute_pipeline(foo_pipeline, instance=instance)
         runner = CliRunner()
         result = runner.invoke(run_delete_command, args=[pipeline_result.run_id], input="Wrong\n")
         assert "Exiting without deleting" in result.output
-        assert result.exit_code == 0
+        assert result.exit_code == 1
 
 
 def test_run_list_limit():
     with instance_for_test():
         runner = CliRunner()
 
-        runner_pipeline_execute(
+        runner_pipeline_or_job_execute(
             runner,
             [
                 "-f",
@@ -600,7 +801,7 @@ def test_run_list_limit():
             ],
         )
 
-        runner_pipeline_execute(
+        runner_pipeline_or_job_execute(
             runner,
             [
                 "-f",
@@ -633,17 +834,23 @@ def test_run_list_limit():
         assert shows_two_results.output.count("Pipeline: multi_mode_with_resources") == 2
 
 
-def runner_pipeline_execute(runner, cli_args):
-    result = runner.invoke(pipeline_execute_command, cli_args)
+def runner_pipeline_or_job_execute(runner, cli_args, using_job_op_graph_apis=False):
+    result = runner.invoke(
+        job_execute_command if using_job_op_graph_apis else pipeline_execute_command, cli_args
+    )
     if result.exit_code != 0:
         # CliRunner captures stdout so printing it out here
         raise Exception(
             (
-                "dagster pipeline execute commands with cli_args {cli_args} "
+                "dagster {pipeline_or_job} execute commands with cli_args {cli_args} "
                 'returned exit_code {exit_code} with stdout:\n"{stdout}" and '
                 '\nresult as string: "{result}"'
             ).format(
-                cli_args=cli_args, exit_code=result.exit_code, stdout=result.stdout, result=result
+                cli_args=cli_args,
+                exit_code=result.exit_code,
+                stdout=result.stdout,
+                result=result,
+                pipeline_or_job="job" if using_job_op_graph_apis else "pipeline",
             )
         )
     return result
