@@ -5,6 +5,7 @@ import pytest
 from click import UsageError
 from click.testing import CliRunner
 from dagster import seven
+from dagster.cli.job import job_list_command
 from dagster.cli.pipeline import execute_list_command, pipeline_list_command
 from dagster.core.test_utils import instance_for_test
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
@@ -31,10 +32,39 @@ def assert_correct_bar_repository_output(result):
         "Solids: (Execution Order)\n"
         "    do_something\n"
         "    do_input\n"
+        "********************\n"
+        "Pipeline: memoizable\n"
+        "Solids: (Execution Order)\n"
+        "    my_solid\n"
         "****************************************\n"
         "Pipeline: partitioned_scheduled_pipeline\n"
         "Solids: (Execution Order)\n"
         "    do_something\n"
+        "******************\n"
+        "Pipeline: quux_job\n"
+        "Solids: (Execution Order)\n"
+        "    do_something_op\n"
+        "*************\n"
+        "Pipeline: qux\n"
+        "Solids: (Execution Order)\n"
+        "    do_something_op\n"
+        "    do_input_op\n"
+    )
+
+
+def assert_correct_job_list_bar_repository_output(result):
+    assert result.exit_code == 0
+    assert result.output == (
+        "Repository bar\n"
+        "**************\n"
+        "Job: quux_job\n"
+        "Ops: (Execution Order)\n"
+        "    do_something_op\n"
+        "********\n"
+        "Job: qux\n"
+        "Ops: (Execution Order)\n"
+        "    do_something_op\n"
+        "    do_input_op\n"
     )
 
 
@@ -46,6 +76,21 @@ def assert_correct_extra_repository_output(result):
         "Pipeline: extra\n"
         "Solids: (Execution Order)\n"
         "    do_something\n"
+        "*******************\n"
+        "Pipeline: extra_job\n"
+        "Solids: (Execution Order)\n"
+        "    do_something\n"
+    )
+
+
+def assert_correct_job_list_extra_repository_output(result):
+    assert result.exit_code == 0
+    assert result.output == (
+        "Repository extra\n"
+        "****************\n"
+        "Job: extra_job\n"
+        "Ops: (Execution Order)\n"
+        "    do_something\n"
     )
 
 
@@ -142,6 +187,12 @@ def test_list_command_cli():
         )
         assert_correct_bar_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command,
+            ["-f", file_relative_path(__file__, "test_cli_commands.py"), "-a", "bar"],
+        )
+        assert_correct_job_list_bar_repository_output(result)
+
         result = runner.invoke(
             pipeline_list_command,
             [
@@ -155,17 +206,41 @@ def test_list_command_cli():
         )
         assert_correct_bar_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command,
+            [
+                "-f",
+                file_relative_path(__file__, "test_cli_commands.py"),
+                "-a",
+                "bar",
+                "-d",
+                os.path.dirname(__file__),
+            ],
+        )
+        assert_correct_job_list_bar_repository_output(result)
+
         result = runner.invoke(
             pipeline_list_command,
             ["-m", "dagster_tests.cli_tests.command_tests.test_cli_commands", "-a", "bar"],
         )
         assert_correct_bar_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command,
+            ["-m", "dagster_tests.cli_tests.command_tests.test_cli_commands", "-a", "bar"],
+        )
+        assert_correct_job_list_bar_repository_output(result)
+
         result = runner.invoke(
             pipeline_list_command, ["-w", file_relative_path(__file__, "workspace.yaml")]
         )
         assert_correct_bar_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command, ["-w", file_relative_path(__file__, "workspace.yaml")]
+        )
+        assert_correct_job_list_bar_repository_output(result)
+
         result = runner.invoke(
             pipeline_list_command,
             [
@@ -177,6 +252,17 @@ def test_list_command_cli():
         )
         assert_correct_extra_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command,
+            [
+                "-w",
+                file_relative_path(__file__, "workspace.yaml"),
+                "-w",
+                file_relative_path(__file__, "override.yaml"),
+            ],
+        )
+        assert_correct_job_list_extra_repository_output(result)
+
         result = runner.invoke(
             pipeline_list_command,
             [
@@ -190,17 +276,41 @@ def test_list_command_cli():
         )
         assert result.exit_code == 2
 
+        result = runner.invoke(
+            job_list_command,
+            [
+                "-f",
+                "foo.py",
+                "-m",
+                "dagster_tests.cli_tests.command_tests.test_cli_commands",
+                "-a",
+                "bar",
+            ],
+        )
+        assert result.exit_code == 2
+
         result = runner.invoke(
             pipeline_list_command,
             ["-m", "dagster_tests.cli_tests.command_tests.test_cli_commands"],
         )
         assert_correct_bar_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command,
+            ["-m", "dagster_tests.cli_tests.command_tests.test_cli_commands"],
+        )
+        assert_correct_job_list_bar_repository_output(result)
+
         result = runner.invoke(
             pipeline_list_command, ["-f", file_relative_path(__file__, "test_cli_commands.py")]
         )
         assert_correct_bar_repository_output(result)
 
+        result = runner.invoke(
+            job_list_command, ["-f", file_relative_path(__file__, "test_cli_commands.py")]
+        )
+        assert_correct_job_list_bar_repository_output(result)
+
 
 def test_list_command():
     with instance_for_test():
@@ -245,3 +355,15 @@ def test_list_command():
                 },
                 no_print,
             )
+
+
+def test_job_command_only_selects_job(capsys):
+    with instance_for_test():
+        runner = CliRunner()
+        result = runner.invoke(
+            job_list_command,
+            ["-f", file_relative_path(__file__, "repo_pipeline_and_job.py"), "-a", "my_repo"],
+        )
+
+        assert "my_job" in result.output
+        assert not "my_pipeline" in result.output
