@@ -12,7 +12,6 @@ from dagster import (
     execute_pipeline,
     lambda_solid,
     pipeline,
-    repository,
     solid,
 )
 from dagster.core.definitions.decorators.hook import event_list_hook, success_hook
@@ -166,7 +165,7 @@ def test_composite_with_duplicate_solids():
     solid_1, solid_2 = get_duplicate_solids()
     with pytest.raises(
         DagsterInvalidDefinitionError,
-        match="Detected conflicting solid definitions with the same name",
+        match="Detected conflicting node definitions with the same name",
     ):
 
         @composite_solid
@@ -179,7 +178,7 @@ def test_pipeline_with_duplicate_solids():
     solid_1, solid_2 = get_duplicate_solids()
     with pytest.raises(
         DagsterInvalidDefinitionError,
-        match="Detected conflicting solid definitions with the same name",
+        match="Detected conflicting node definitions with the same name",
     ):
 
         @pipeline
@@ -458,26 +457,6 @@ def test_pipeline_has_solid_def():
     assert a_pipeline.has_solid_def("inner")
 
 
-def test_repository_has_solid_def():
-    @composite_solid(output_defs=[OutputDefinition()])
-    def inner():
-        return add_one(return_one())
-
-    @composite_solid
-    def outer():
-        add_one(inner())
-
-    @pipeline
-    def a_pipeline():
-        outer()
-
-    @repository
-    def has_solid_def_test():
-        return [a_pipeline]
-
-    assert has_solid_def_test.solid_def_named("inner")
-
-
 def test_mapping_args_ordering():
     @lambda_solid
     def take(a, b, c):
