@@ -1,3 +1,4 @@
+import json
 import os
 import re
 import sys
@@ -6,9 +7,19 @@ import time
 from contextlib import contextmanager
 
 import pytest
-from dagster import DefaultRunLauncher, file_relative_path, pipeline, repository, seven, solid
+from dagster import (
+    DefaultRunLauncher,
+    ModeDefinition,
+    file_relative_path,
+    fs_io_manager,
+    pipeline,
+    repository,
+    seven,
+    solid,
+)
 from dagster.core.errors import DagsterLaunchFailedError
 from dagster.core.storage.pipeline_run import PipelineRunStatus
+from dagster.core.storage.tags import GRPC_INFO_TAG
 from dagster.core.test_utils import (
     environ,
     instance_for_test,
@@ -19,7 +30,11 @@ from dagster.core.test_utils import (
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster.core.workspace import WorkspaceProcessContext
 from dagster.core.workspace.load_target import GrpcServerTarget, PythonFileTarget
+from dagster.grpc.client import DagsterGrpcClient
 from dagster.grpc.server import GrpcServerProcess
+from dagster.grpc.types import CancelExecutionRequest
+
+default_mode_def = ModeDefinition(resource_defs={"io_manager": fs_io_manager})
 
 
 @solid
@@ -27,7 +42,7 @@ def noop_solid(_):
     pass
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def])
 def noop_pipeline():
     pass
 
@@ -37,18 +52,28 @@ def crashy_solid(_):
     os._exit(1)  # pylint: disable=W0212
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def])
 def crashy_pipeline():
     crashy_solid()
 
 
+@solid
+def exity_solid(_):
+    sys.exit(1)  # pylint: disable=W0212
+
+
+@pipeline(mode_defs=[default_mode_def])
+def exity_pipeline():
+    exity_solid()
+
+
 @solid
 def sleepy_solid(_):
     while True:
         time.sleep(0.1)
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def])
 def sleepy_pipeline():
     sleepy_solid()
 
@@ -58,7 +83,7 @@ def slow_solid(_):
     time.sleep(4)
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def])
 def slow_pipeline():
     slow_solid()
 
@@ -83,7 +108,7 @@ def add(_, num1, num2):
     return num1 + num2
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def])
 def math_diamond():
     one = return_one()
     add(multiply_by_2(one), multiply_by_3(one))
@@ -91,7 +116,14 @@ def math_diamond():
 
 @repository
 def nope():
-    return [noop_pipeline, crashy_pipeline, sleepy_pipeline, slow_pipeline, math_diamond]
+    return [
+        noop_pipeline,
+        crashy_pipeline,
+        exity_pipeline,
+        sleepy_pipeline,
+        slow_pipeline,
+        math_diamond,
+    ]
 
 
 @contextmanager
@@ -136,7 +168,7 @@ def get_managed_grpc_server_workspace(instance):
 def run_configs():
     return [
         None,
-        {"execution": {"multiprocess": {}}, "intermediate_storage": {"filesystem": {}}},
+        {"execution": {"multiprocess": {}}},
     ]
 
 
@@ -304,13 +336,58 @@ def test_crashy_run(get_workspace, run_config):  # pylint: disable=redefined-out
                     "step crashy_solid unexpectedly exited"
                 )
             else:
-                message = "Pipeline execution process for {run_id} unexpectedly exited".format(
+                message = "Run execution process for {run_id} unexpectedly exited".format(
                     run_id=run_id
                 )
 
             assert _message_exists(event_records, message)
 
 
+@pytest.mark.parametrize("run_config", run_configs())
+@pytest.mark.skipif(
+    seven.IS_WINDOWS,
+    reason="Crashy pipelines leave resources open on windows, causing filesystem contention",
+)
+def test_exity_run(run_config):  # pylint: disable=redefined-outer-name
+    with instance_for_test() as instance:
+        with get_managed_grpc_server_workspace(instance) as workspace:
+
+            external_pipeline = (
+                workspace.get_repository_location("test")
+                .get_repository("nope")
+                .get_full_external_pipeline("exity_pipeline")
+            )
+
+            pipeline_run = instance.create_run_for_pipeline(
+                pipeline_def=exity_pipeline,
+                run_config=run_config,
+                external_pipeline_origin=external_pipeline.get_external_origin(),
+                pipeline_code_origin=external_pipeline.get_python_origin(),
+            )
+
+            run_id = pipeline_run.run_id
+
+            assert instance.get_run_by_id(run_id).status == PipelineRunStatus.NOT_STARTED
+
+            instance.launch_run(pipeline_run.run_id, workspace)
+
+            failed_pipeline_run = instance.get_run_by_id(run_id)
+
+            assert failed_pipeline_run
+            assert failed_pipeline_run.run_id == run_id
+
+            failed_pipeline_run = poll_for_finished_run(instance, run_id, timeout=5)
+            assert failed_pipeline_run.status == PipelineRunStatus.FAILURE
+
+            event_records = instance.all_logs(run_id)
+
+            assert _message_exists(event_records, 'Execution of step "exity_solid" failed.')
+            assert _message_exists(
+                event_records,
+                'Execution of run for "exity_pipeline" failed. An exception was thrown during execution.',
+            )
+
+
 @pytest.mark.parametrize(
     "get_workspace",
     [
@@ -357,7 +434,7 @@ def test_terminated_run(get_workspace, run_config):  # pylint: disable=redefined
                 instance,
                 run_id,
                 event_type="ENGINE_EVENT",
-                message="Process for pipeline exited",
+                message="Process for run exited",
             )
 
             run_logs = instance.all_logs(run_id)
@@ -366,7 +443,7 @@ def test_terminated_run(get_workspace, run_config):  # pylint: disable=redefined
                 _check_event_log_contains(
                     run_logs,
                     [
-                        ("PIPELINE_CANCELING", "Sending pipeline termination request."),
+                        ("PIPELINE_CANCELING", "Sending run termination request."),
                         (
                             "ENGINE_EVENT",
                             "Multiprocess executor: received termination signal - forwarding to active child process",
@@ -378,26 +455,83 @@ def test_terminated_run(get_workspace, run_config):  # pylint: disable=redefined
                         ("STEP_FAILURE", 'Execution of step "sleepy_solid" failed.'),
                         (
                             "PIPELINE_CANCELED",
-                            'Execution of pipeline "sleepy_pipeline" canceled.',
+                            'Execution of run for "sleepy_pipeline" canceled.',
                         ),
-                        ("ENGINE_EVENT", "Process for pipeline exited"),
+                        ("ENGINE_EVENT", "Process for run exited"),
                     ],
                 )
             else:
                 _check_event_log_contains(
                     run_logs,
                     [
-                        ("PIPELINE_CANCELING", "Sending pipeline termination request."),
+                        ("PIPELINE_CANCELING", "Sending run termination request."),
                         ("STEP_FAILURE", 'Execution of step "sleepy_solid" failed.'),
                         (
                             "PIPELINE_CANCELED",
-                            'Execution of pipeline "sleepy_pipeline" canceled.',
+                            'Execution of run for "sleepy_pipeline" canceled.',
                         ),
-                        ("ENGINE_EVENT", "Process for pipeline exited"),
+                        ("ENGINE_EVENT", "Process for run exited"),
                     ],
                 )
 
 
+@pytest.mark.parametrize("run_config", run_configs())
+def test_cleanup_after_force_terminate(run_config):
+    with instance_for_test() as instance, get_managed_grpc_server_workspace(instance) as workspace:
+        external_pipeline = (
+            workspace.get_repository_location("test")
+            .get_repository("nope")
+            .get_full_external_pipeline("sleepy_pipeline")
+        )
+        pipeline_run = instance.create_run_for_pipeline(
+            pipeline_def=sleepy_pipeline,
+            run_config=run_config,
+            external_pipeline_origin=external_pipeline.get_external_origin(),
+            pipeline_code_origin=external_pipeline.get_python_origin(),
+        )
+
+        run_id = pipeline_run.run_id
+
+        instance.launch_run(pipeline_run.run_id, workspace)
+
+        poll_for_step_start(instance, run_id)
+
+        # simulate the sequence of events that happen during force-termination:
+        # run moves immediately into canceled status while termination happens
+        instance.report_run_canceling(pipeline_run)
+
+        instance.report_run_canceled(pipeline_run)
+
+        reloaded_run = instance.get_run_by_id(run_id)
+        grpc_info = json.loads(reloaded_run.tags.get(GRPC_INFO_TAG))
+        client = DagsterGrpcClient(
+            port=grpc_info.get("port"),
+            socket=grpc_info.get("socket"),
+            host=grpc_info.get("host"),
+        )
+        client.cancel_execution(CancelExecutionRequest(run_id=run_id))
+
+        # Wait for the run worker to clean up
+        start_time = time.time()
+        while True:
+            if time.time() - start_time > 30:
+                raise Exception("Timed out waiting for cleanup message")
+
+            logs = instance.all_logs(run_id)
+            if any(
+                [
+                    "Computational resources were cleaned up after the run was forcibly marked as canceled."
+                    in str(event)
+                    for event in logs
+                ]
+            ):
+                break
+
+            time.sleep(1)
+
+        assert instance.get_run_by_id(run_id).status == PipelineRunStatus.CANCELED
+
+
 def _get_engine_events(event_records):
     return [er for er in event_records if er.dagster_event and er.dagster_event.is_engine_event]
 
@@ -552,7 +686,7 @@ def test_engine_events(get_workspace, run_config):  # pylint: disable=redefined-
             assert finished_pipeline_run.status == PipelineRunStatus.SUCCESS
 
             poll_for_event(
-                instance, run_id, event_type="ENGINE_EVENT", message="Process for pipeline exited"
+                instance, run_id, event_type="ENGINE_EVENT", message="Process for run exited"
             )
             event_records = instance.all_logs(run_id)
 
@@ -560,7 +694,7 @@ def test_engine_events(get_workspace, run_config):  # pylint: disable=redefined-
 
             if _is_multiprocess(run_config):
                 messages = [
-                    "Started process for pipeline",
+                    "Started process for run",
                     "Executing steps using multiprocess executor",
                     "Launching subprocess for return_one",
                     "Executing step return_one in subprocess",
@@ -580,16 +714,16 @@ def test_engine_events(get_workspace, run_config):  # pylint: disable=redefined-
                     "Starting initialization of resources",
                     "Finished initialization of resources",
                     "Multiprocess executor: parent process exiting",
-                    "Process for pipeline exited",
+                    "Process for run exited",
                 ]
             else:
                 messages = [
-                    "Started process for pipeline",
+                    "Started process for run",
                     "Executing steps in process",
                     "Starting initialization of resources",
                     "Finished initialization of resources",
                     "Finished steps in process",
-                    "Process for pipeline exited",
+                    "Process for run exited",
                 ]
 
             events_iter = iter(engine_events)
