@@ -4,19 +4,24 @@ import tempfile
 import mock
 import pytest
 from dagster import (
+    AssetKey,
     AssetMaterialization,
     DagsterInstance,
     DagsterInvalidDefinitionError,
-    DagsterInvariantViolationError,
     Field,
     IOManagerDefinition,
+    In,
     InputDefinition,
     ModeDefinition,
+    Out,
     OutputDefinition,
     build_input_context,
     build_output_context,
     composite_solid,
     execute_pipeline,
+    graph,
+    job,
+    op,
     pipeline,
     reexecute_pipeline,
     resource,
@@ -24,6 +29,7 @@ from dagster import (
 )
 from dagster.check import CheckError
 from dagster.core.definitions.pipeline_base import InMemoryPipeline
+from dagster.core.definitions.time_window_partitions import DailyPartitionsDefinition
 from dagster.core.execution.api import create_execution_plan, execute_plan
 from dagster.core.execution.context.output import get_output_context
 from dagster.core.execution.plan.outputs import StepOutputHandle
@@ -423,65 +429,6 @@ def my_io_manager(_):
     pass
 
 
-def test_set_io_manager_and_intermediate_storage():
-    from dagster import intermediate_storage, fs_intermediate_storage
-
-    @intermediate_storage()
-    def my_intermediate_storage(_):
-        pass
-
-    with pytest.raises(DagsterInvariantViolationError):
-
-        @pipeline(
-            mode_defs=[
-                ModeDefinition(
-                    resource_defs={"io_manager": my_io_manager},
-                    intermediate_storage_defs=[my_intermediate_storage, fs_intermediate_storage],
-                )
-            ]
-        )
-        def my_pipeline():
-            pass
-
-        execute_pipeline(my_pipeline)
-
-
-def test_set_io_manager_configure_intermediate_storage():
-    with pytest.raises(DagsterInvariantViolationError):
-
-        @pipeline(mode_defs=[ModeDefinition(resource_defs={"io_manager": my_io_manager})])
-        def my_pipeline():
-            pass
-
-        execute_pipeline(my_pipeline, run_config={"intermediate_storage": {"filesystem": {}}})
-
-
-def test_io_manager_key_intermediate_storage():
-    called = {"called": False}
-
-    @io_manager
-    def custom_io_manager(_):
-        class CustomIOManager(IOManager):
-            def handle_output(self, _, _obj):
-                called["called"] = True
-
-            def load_input(self, _):
-                pass
-
-        return CustomIOManager()
-
-    @solid(output_defs=[OutputDefinition(io_manager_key="my_key")])
-    def solid1(_):
-        return 5
-
-    @pipeline(mode_defs=[ModeDefinition(resource_defs={"my_key": custom_io_manager})])
-    def my_pipeline():
-        solid1()
-
-    execute_pipeline(my_pipeline, run_config={"intermediate_storage": {"filesystem": {}}})
-    assert called["called"]
-
-
 def test_fan_in():
     with tempfile.TemporaryDirectory() as tmpdir_path:
         default_io_manager = fs_io_manager.configured({"base_dir": tmpdir_path})
@@ -715,6 +662,33 @@ def test_error_boundary_with_gen():
     assert step_failure.event_specific_data.error.cls_name == "DagsterExecutionHandleOutputError"
 
 
+def test_handle_output_exception_raised():
+    class ErrorIOManager(IOManager):
+        def load_input(self, context):
+            pass
+
+        def handle_output(self, context, obj):
+            raise ValueError("handle output error")
+
+    @io_manager
+    def error_io_manager(_):
+        return ErrorIOManager()
+
+    @op
+    def basic_op():
+        return 5
+
+    @job(resource_defs={"io_manager": error_io_manager})
+    def single_op_job():
+        basic_op()
+
+    result = single_op_job.execute_in_process(raise_on_error=False)
+    step_failure = [
+        event for event in result.all_node_events if event.event_type_value == "STEP_FAILURE"
+    ][0]
+    assert step_failure.event_specific_data.error.cls_name == "DagsterExecutionHandleOutputError"
+
+
 def test_output_identifier_dynamic_memoization():
     context = build_output_context(version="foo", mapping_key="bar", step_key="baz", name="buzz")
 
@@ -724,3 +698,62 @@ def test_output_identifier_dynamic_memoization():
         "mapping is not supported when using versioning.",
     ):
         context.get_output_identifier()
+
+
+def test_asset_key():
+    in_asset_key = AssetKey(["a", "b"])
+    out_asset_key = AssetKey(["c", "d"])
+
+    @op(out=Out(asset_key=out_asset_key))
+    def before():
+        pass
+
+    @op(ins={"a": In(asset_key=in_asset_key)}, out={})
+    def after(a):
+        assert a
+
+    class MyIOManager(IOManager):
+        def load_input(self, context):
+            assert context.asset_key == in_asset_key
+            assert context.upstream_output.asset_key == out_asset_key
+            return 1
+
+        def handle_output(self, context, obj):
+            assert context.asset_key == out_asset_key
+
+    @graph
+    def my_graph():
+        after(before())
+
+    result = my_graph.to_job(
+        resource_defs={"io_manager": IOManagerDefinition.hardcoded_io_manager(MyIOManager())}
+    ).execute_in_process()
+    assert result.success
+
+
+def test_partition_key():
+    @op
+    def my_op():
+        pass
+
+    @op
+    def my_op2(_input1):
+        pass
+
+    class MyIOManager(IOManager):
+        def load_input(self, context):
+            assert context.has_partition_key
+            assert context.partition_key == "2020-01-01"
+
+        def handle_output(self, context, _obj):
+            assert context.has_partition_key
+            assert context.partition_key == "2020-01-01"
+
+    @job(
+        partitions_def=DailyPartitionsDefinition(start_date="2020-01-01"),
+        resource_defs={"io_manager": IOManagerDefinition.hardcoded_io_manager(MyIOManager())},
+    )
+    def my_job():
+        my_op2(my_op())
+
+    assert my_job.execute_in_process(partition_key="2020-01-01").success
