@@ -13,6 +13,7 @@ from dagster import (
     Any,
     AssetKey,
     AssetMaterialization,
+    AssetObservation,
     Field,
     Output,
     graph,
@@ -24,13 +25,9 @@ from dagster import (
 )
 from dagster.core.definitions.decorators.sensor import asset_sensor, sensor
 from dagster.core.definitions.reconstructable import ReconstructableRepository
-from dagster.core.definitions.run_request import JobType
+from dagster.core.definitions.run_request import InstigatorType
 from dagster.core.definitions.run_status_sensor_definition import run_status_sensor
-from dagster.core.definitions.sensor_definition import (
-    DEFAULT_SENSOR_DAEMON_INTERVAL,
-    RunRequest,
-    SkipReason,
-)
+from dagster.core.definitions.sensor_definition import RunRequest, SkipReason
 from dagster.core.events import DagsterEvent, DagsterEventType
 from dagster.core.events.log import EventLogEntry
 from dagster.core.execution.api import execute_pipeline
@@ -41,7 +38,7 @@ from dagster.core.host_representation import (
     ManagedGrpcPythonEnvRepositoryLocationOrigin,
 )
 from dagster.core.instance import DagsterInstance
-from dagster.core.scheduler.job import JobState, JobStatus, JobTickStatus
+from dagster.core.scheduler.instigation import InstigatorState, InstigatorStatus, TickStatus
 from dagster.core.storage.event_log.base import EventRecordsFilter
 from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.core.test_utils import (
@@ -104,6 +101,17 @@ def foo_pipeline():
     foo_solid()
 
 
+@solid
+def foo_observation_solid():
+    yield AssetObservation(asset_key=AssetKey("foo"), metadata={"text": "FOO"})
+    yield Output(5)
+
+
+@pipeline
+def foo_observation_pipeline():
+    foo_observation_solid()
+
+
 @solid
 def hanging_solid():
     start_time = time.time()
@@ -360,13 +368,13 @@ def validate_tick(
     tick_data = tick.job_tick_data
     assert tick_data.job_origin_id == external_sensor.get_external_origin_id()
     assert tick_data.job_name == external_sensor.name
-    assert tick_data.job_type == JobType.SENSOR
+    assert tick_data.job_type == InstigatorType.SENSOR
     assert tick_data.status == expected_status
     assert tick_data.timestamp == expected_datetime.timestamp()
     if expected_run_ids is not None:
         assert set(tick_data.run_ids) == set(expected_run_ids)
     if expected_error:
-        assert expected_error in tick_data.error.message
+        assert expected_error in str(tick_data.error)
 
 
 def validate_run_started(run, expected_success=True):
@@ -429,7 +437,11 @@ def test_simple_sensor(external_repo_context, capfd):
         with pendulum.test(freeze_datetime):
             external_sensor = external_repo.get_external_sensor("simple_sensor")
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
@@ -444,13 +456,13 @@ def test_simple_sensor(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             assert (
-                get_logger_output_from_capfd(capfd, "SensorDaemon")
-                == """2019-02-27 17:59:59 -0600 - SensorDaemon - INFO - Checking for new runs for sensor: simple_sensor
-2019-02-27 17:59:59 -0600 - SensorDaemon - INFO - Sensor returned false for simple_sensor, skipping"""
+                get_logger_output_from_capfd(capfd, "dagster.daemon.SensorDaemon")
+                == """2019-02-27 17:59:59 -0600 - dagster.daemon.SensorDaemon - INFO - Checking for new runs for sensor: simple_sensor
+2019-02-27 17:59:59 -0600 - dagster.daemon.SensorDaemon - INFO - No run requests returned for simple_sensor, skipping"""
             )
 
             freeze_datetime = freeze_datetime.add(seconds=30)
@@ -471,15 +483,15 @@ def test_simple_sensor(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 expected_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
                 [run.run_id],
             )
 
             assert (
-                get_logger_output_from_capfd(capfd, "SensorDaemon")
-                == """2019-02-27 18:00:29 -0600 - SensorDaemon - INFO - Checking for new runs for sensor: simple_sensor
-2019-02-27 18:00:29 -0600 - SensorDaemon - INFO - Launching run for simple_sensor
-2019-02-27 18:00:29 -0600 - SensorDaemon - INFO - Completed launch of run {run_id} for simple_sensor""".format(
+                get_logger_output_from_capfd(capfd, "dagster.daemon.SensorDaemon")
+                == """2019-02-27 18:00:29 -0600 - dagster.daemon.SensorDaemon - INFO - Checking for new runs for sensor: simple_sensor
+2019-02-27 18:00:29 -0600 - dagster.daemon.SensorDaemon - INFO - Launching run for simple_sensor
+2019-02-27 18:00:29 -0600 - dagster.daemon.SensorDaemon - INFO - Completed launch of run {run_id} for simple_sensor""".format(
                     run_id=run.run_id
                 )
             )
@@ -510,7 +522,11 @@ def test_bad_load_sensor_repository(external_repo_context, capfd):
                 valid_origin.job_name,
             )
 
-            instance.add_job_state(JobState(invalid_repo_origin, JobType.SENSOR, JobStatus.RUNNING))
+            instance.add_job_state(
+                InstigatorState(
+                    invalid_repo_origin, InstigatorType.SENSOR, InstigatorStatus.RUNNING
+                )
+            )
 
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(invalid_repo_origin.get_id())
@@ -552,7 +568,11 @@ def test_bad_load_sensor(external_repo_context, capfd):
                 "invalid_sensor",
             )
 
-            instance.add_job_state(JobState(invalid_repo_origin, JobType.SENSOR, JobStatus.RUNNING))
+            instance.add_job_state(
+                InstigatorState(
+                    invalid_repo_origin, InstigatorType.SENSOR, InstigatorStatus.RUNNING
+                )
+            )
 
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(invalid_repo_origin.get_id())
@@ -583,7 +603,11 @@ def test_error_sensor(external_repo_context, capfd):
         with pendulum.test(freeze_datetime):
             external_sensor = external_repo.get_external_sensor("error_sensor")
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
@@ -598,7 +622,7 @@ def test_error_sensor(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.FAILURE,
+                TickStatus.FAILURE,
                 [],
                 "Error occurred during the execution of evaluation_fn for sensor error_sensor",
             )
@@ -630,7 +654,11 @@ def test_wrong_config_sensor(external_repo_context, capfd):
         with pendulum.test(freeze_datetime):
             external_sensor = external_repo.get_external_sensor("wrong_config_sensor")
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
@@ -645,7 +673,7 @@ def test_wrong_config_sensor(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.FAILURE,
+                TickStatus.FAILURE,
                 [],
                 "Error in config for pipeline",
             )
@@ -664,7 +692,7 @@ def test_wrong_config_sensor(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.FAILURE,
+                TickStatus.FAILURE,
                 [],
                 "Error in config for pipeline",
             )
@@ -692,7 +720,11 @@ def test_launch_failure(external_repo_context, capfd):
 
             external_sensor = external_repo.get_external_sensor("always_on_sensor")
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
@@ -705,7 +737,11 @@ def test_launch_failure(external_repo_context, capfd):
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
             assert len(ticks) == 1
             validate_tick(
-                ticks[0], external_sensor, freeze_datetime, JobTickStatus.SUCCESS, [run.run_id]
+                ticks[0],
+                external_sensor,
+                freeze_datetime,
+                TickStatus.SUCCESS,
+                [run.run_id],
             )
 
             captured = capfd.readouterr()
@@ -739,7 +775,11 @@ def test_launch_once(external_repo_context, capfd):
 
             external_sensor = external_repo.get_external_sensor("run_key_sensor")
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
             assert instance.get_runs_count() == 0
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
@@ -756,7 +796,7 @@ def test_launch_once(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
                 expected_run_ids=[run.run_id],
             )
 
@@ -771,7 +811,7 @@ def test_launch_once(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
             captured = capfd.readouterr()
             assert (
@@ -800,7 +840,7 @@ def test_launch_once(external_repo_context, capfd):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
 
@@ -817,7 +857,11 @@ def test_custom_interval_sensor(external_repo_context):
         with pendulum.test(freeze_datetime):
             external_sensor = external_repo.get_external_sensor("custom_interval_sensor")
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
             assert len(ticks) == 0
@@ -825,7 +869,7 @@ def test_custom_interval_sensor(external_repo_context):
             evaluate_sensors(instance, workspace)
             ticks = instance.get_job_ticks(external_sensor.get_external_origin_id())
             assert len(ticks) == 1
-            validate_tick(ticks[0], external_sensor, freeze_datetime, JobTickStatus.SKIPPED)
+            validate_tick(ticks[0], external_sensor, freeze_datetime, TickStatus.SKIPPED)
 
             freeze_datetime = freeze_datetime.add(seconds=30)
 
@@ -843,7 +887,7 @@ def test_custom_interval_sensor(external_repo_context):
             assert len(ticks) == 2
 
             expected_datetime = create_pendulum_time(year=2019, month=2, day=28, hour=0, minute=1)
-            validate_tick(ticks[0], external_sensor, expected_datetime, JobTickStatus.SKIPPED)
+            validate_tick(ticks[0], external_sensor, expected_datetime, TickStatus.SKIPPED)
 
 
 @pytest.mark.parametrize("external_repo_context", repos())
@@ -871,7 +915,11 @@ def test_custom_interval_sensor_with_offset(external_repo_context, monkeypatch):
             external_sensor = external_repo.get_external_sensor("custom_interval_sensor")
 
             instance.add_job_state(
-                JobState(external_sensor.get_external_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    external_sensor.get_external_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
 
             # create a tick
@@ -891,7 +939,7 @@ def test_custom_interval_sensor_with_offset(external_repo_context, monkeypatch):
                 execute_sensor_iteration_loop(
                     instance,
                     workspace,
-                    get_default_daemon_logger("SensorDaemon"),
+                    get_default_daemon_logger("dagster.daemon.SensorDaemon"),
                     until=freeze_datetime.add(seconds=65).timestamp(),
                 )
             )
@@ -940,11 +988,15 @@ def test_error_sensor_daemon(external_repo_context, monkeypatch):
 
         with pendulum.test(freeze_datetime):
             instance.add_job_state(
-                JobState(_get_unloadable_sensor_origin(), JobType.SENSOR, JobStatus.RUNNING)
+                InstigatorState(
+                    _get_unloadable_sensor_origin(),
+                    InstigatorType.SENSOR,
+                    InstigatorStatus.RUNNING,
+                )
             )
-            sensor_daemon = SensorDaemon(interval_seconds=DEFAULT_SENSOR_DAEMON_INTERVAL)
+            sensor_daemon = SensorDaemon()
             daemon_shutdown_event = threading.Event()
-            sensor_daemon.run_loop(
+            sensor_daemon.run_daemon_loop(
                 instance.get_ref(),
                 "my_uuid",
                 daemon_shutdown_event,
@@ -988,7 +1040,11 @@ def test_sensor_start_stop(external_repo_context):
             ticks = instance.get_job_ticks(external_origin_id)
             assert len(ticks) == 1
             validate_tick(
-                ticks[0], external_sensor, freeze_datetime, JobTickStatus.SUCCESS, [run.run_id]
+                ticks[0],
+                external_sensor,
+                freeze_datetime,
+                TickStatus.SUCCESS,
+                [run.run_id],
             )
 
             freeze_datetime = freeze_datetime.add(seconds=15)
@@ -1041,7 +1097,7 @@ def test_large_sensor(external_repo_context):
                 ticks[0],
                 external_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
 
 
@@ -1069,7 +1125,7 @@ def test_cursor_sensor(external_repo_context):
                 skip_ticks[0],
                 skip_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
             assert skip_ticks[0].cursor == "1"
 
@@ -1079,7 +1135,7 @@ def test_cursor_sensor(external_repo_context):
                 run_ticks[0],
                 run_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
             assert run_ticks[0].cursor == "1"
 
@@ -1093,7 +1149,7 @@ def test_cursor_sensor(external_repo_context):
                 skip_ticks[0],
                 skip_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
             assert skip_ticks[0].cursor == "2"
 
@@ -1103,7 +1159,7 @@ def test_cursor_sensor(external_repo_context):
                 run_ticks[0],
                 run_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
             assert run_ticks[0].cursor == "2"
 
@@ -1131,7 +1187,7 @@ def test_asset_sensor(external_repo_context):
                 ticks[0],
                 foo_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1148,7 +1204,7 @@ def test_asset_sensor(external_repo_context):
                 ticks[0],
                 foo_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
             run = instance.get_runs()[0]
             assert run.run_config == {}
@@ -1179,7 +1235,7 @@ def test_asset_job_sensor(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1196,7 +1252,7 @@ def test_asset_job_sensor(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
             run = instance.get_runs()[0]
             assert run.run_config == {}
@@ -1204,6 +1260,58 @@ def test_asset_job_sensor(external_repo_context):
             assert run.tags.get("dagster/sensor_name") == "asset_job_sensor"
 
 
+@pytest.mark.parametrize("external_repo_context", repos())
+def test_asset_sensor_not_triggered_on_observation(external_repo_context):
+    freeze_datetime = to_timezone(
+        create_pendulum_time(year=2019, month=2, day=27, tz="UTC"),
+        "US/Central",
+    )
+    with instance_with_sensors(external_repo_context) as (
+        instance,
+        workspace,
+        external_repo,
+    ):
+        with pendulum.test(freeze_datetime):
+            foo_sensor = external_repo.get_external_sensor("asset_foo_sensor")
+            instance.start_sensor(foo_sensor)
+
+            # generates the foo asset observation
+            execute_pipeline(foo_observation_pipeline, instance=instance)
+
+            # observation should not fire the asset sensor
+            evaluate_sensors(instance, workspace)
+
+            ticks = instance.get_job_ticks(foo_sensor.get_external_origin_id())
+            assert len(ticks) == 1
+            validate_tick(
+                ticks[0],
+                foo_sensor,
+                freeze_datetime,
+                TickStatus.SKIPPED,
+            )
+
+            freeze_datetime = freeze_datetime.add(seconds=60)
+        with pendulum.test(freeze_datetime):
+
+            # should generate the foo asset
+            execute_pipeline(foo_pipeline, instance=instance)
+
+            # materialization should fire the asset sensor
+            evaluate_sensors(instance, workspace)
+            ticks = instance.get_job_ticks(foo_sensor.get_external_origin_id())
+            assert len(ticks) == 2
+            validate_tick(
+                ticks[0],
+                foo_sensor,
+                freeze_datetime,
+                TickStatus.SUCCESS,
+            )
+            run = instance.get_runs()[0]
+            assert run.run_config == {}
+            assert run.tags
+            assert run.tags.get("dagster/sensor_name") == "asset_foo_sensor"
+
+
 @pytest.mark.parametrize("external_repo_context", repos())
 def test_pipeline_failure_sensor(external_repo_context):
     freeze_datetime = pendulum.now()
@@ -1224,7 +1332,7 @@ def test_pipeline_failure_sensor(external_repo_context):
                 ticks[0],
                 failure_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1254,7 +1362,7 @@ def test_pipeline_failure_sensor(external_repo_context):
                 ticks[0],
                 failure_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
 
 
@@ -1278,7 +1386,7 @@ def test_run_failure_sensor_filtered(external_repo_context):
                 ticks[0],
                 failure_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1308,7 +1416,7 @@ def test_run_failure_sensor_filtered(external_repo_context):
                 ticks[0],
                 failure_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1339,7 +1447,7 @@ def test_run_failure_sensor_filtered(external_repo_context):
                 ticks[0],
                 failure_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
 
 
@@ -1363,7 +1471,7 @@ def test_run_status_sensor(external_repo_context):
                 ticks[0],
                 success_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
             freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1393,7 +1501,7 @@ def test_run_status_sensor(external_repo_context):
                 ticks[0],
                 success_sensor,
                 freeze_datetime,
-                JobTickStatus.SKIPPED,
+                TickStatus.SKIPPED,
             )
 
         with pendulum.test(freeze_datetime):
@@ -1420,7 +1528,7 @@ def test_run_status_sensor(external_repo_context):
                 ticks[0],
                 success_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
 
 
@@ -1484,7 +1592,7 @@ def test_run_status_sensor_interleave(external_repo_context, storage_config_fn):
                     ticks[0],
                     failure_sensor,
                     freeze_datetime,
-                    JobTickStatus.SKIPPED,
+                    TickStatus.SKIPPED,
                 )
 
                 freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1527,7 +1635,7 @@ def test_run_status_sensor_interleave(external_repo_context, storage_config_fn):
                     ticks[0],
                     failure_sensor,
                     freeze_datetime,
-                    JobTickStatus.SUCCESS,
+                    TickStatus.SUCCESS,
                 )
                 assert len(ticks[0].origin_run_ids) == 1
                 assert ticks[0].origin_run_ids[0] == run2.run_id
@@ -1551,7 +1659,7 @@ def test_run_status_sensor_interleave(external_repo_context, storage_config_fn):
                     ticks[0],
                     failure_sensor,
                     freeze_datetime,
-                    JobTickStatus.SUCCESS,
+                    TickStatus.SUCCESS,
                 )
                 assert len(ticks[0].origin_run_ids) == 1
                 assert ticks[0].origin_run_ids[0] == run1.run_id
@@ -1583,7 +1691,7 @@ def test_pipeline_failure_sensor_empty_run_records(external_repo_context, storag
                     ticks[0],
                     failure_sensor,
                     freeze_datetime,
-                    JobTickStatus.SKIPPED,
+                    TickStatus.SKIPPED,
                 )
 
                 freeze_datetime = freeze_datetime.add(seconds=60)
@@ -1623,7 +1731,7 @@ def test_pipeline_failure_sensor_empty_run_records(external_repo_context, storag
                     ticks[0],
                     failure_sensor,
                     freeze_datetime,
-                    JobTickStatus.SKIPPED,
+                    TickStatus.SKIPPED,
                 )
 
 
@@ -1650,7 +1758,7 @@ def test_multi_job_sensor(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
 
             run = instance.get_runs()[0]
@@ -1669,7 +1777,7 @@ def test_multi_job_sensor(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.SUCCESS,
+                TickStatus.SUCCESS,
             )
             run = instance.get_runs()[0]
             assert run.run_config == {"solids": {"config_solid": {"config": {"foo": "blah"}}}}
@@ -1701,7 +1809,7 @@ def test_bad_run_request_untargeted(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.FAILURE,
+                TickStatus.FAILURE,
                 None,
                 (
                     "Error in sensor bad_request_untargeted: Sensor evaluation function returned a "
@@ -1733,7 +1841,7 @@ def test_bad_run_request_mismatch(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.FAILURE,
+                TickStatus.FAILURE,
                 None,
                 (
                     "Error in sensor bad_request_mismatch: Sensor returned a RunRequest with "
@@ -1765,7 +1873,7 @@ def test_bad_run_request_unspecified(external_repo_context):
                 ticks[0],
                 job_sensor,
                 freeze_datetime,
-                JobTickStatus.FAILURE,
+                TickStatus.FAILURE,
                 None,
                 (
                     "Error in sensor bad_request_unspecified: Sensor returned a RunRequest that "
